# coding: utf-8

"""
Perigon API

The Perigon API provides access to comprehensive news and web content data. To use the API, simply sign up for a Perigon Business Solutions account to obtain your API key. Your available features may vary based on your plan. See the Authentication section for details on how to use your API key.

The version of the OpenAPI document: 1.0.0
Contact: data@perigon.io
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing_extensions import Self

from perigon.models.coordinate import Coordinate


class Place(BaseModel):
    """
    Place
    """  # noqa: E501

    osm_id: Optional[StrictStr] = Field(default=None, alias="osmId")
    road: Optional[StrictStr] = None
    quarter: Optional[StrictStr] = None
    suburb: Optional[StrictStr] = None
    city: Optional[StrictStr] = None
    town: Optional[StrictStr] = None
    county: Optional[StrictStr] = None
    state_district: Optional[StrictStr] = Field(default=None, alias="stateDistrict")
    state: Optional[StrictStr] = None
    postcode: Optional[StrictStr] = None
    country: Optional[StrictStr] = None
    country_code: Optional[StrictStr] = Field(default=None, alias="countryCode")
    amenity: Optional[StrictStr] = None
    neighbourhood: Optional[StrictStr] = None
    coordinates: Optional[Coordinate] = None
    __properties: ClassVar[List[str]] = [
        "osmId",
        "road",
        "quarter",
        "suburb",
        "city",
        "town",
        "county",
        "stateDistrict",
        "state",
        "postcode",
        "country",
        "countryCode",
        "amenity",
        "neighbourhood",
        "coordinates",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Place from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of coordinates
        if self.coordinates:
            _dict["coordinates"] = self.coordinates.to_dict()
        # set to None if osm_id (nullable) is None
        # and model_fields_set contains the field
        if self.osm_id is None and "osm_id" in self.model_fields_set:
            _dict["osmId"] = None

        # set to None if road (nullable) is None
        # and model_fields_set contains the field
        if self.road is None and "road" in self.model_fields_set:
            _dict["road"] = None

        # set to None if quarter (nullable) is None
        # and model_fields_set contains the field
        if self.quarter is None and "quarter" in self.model_fields_set:
            _dict["quarter"] = None

        # set to None if suburb (nullable) is None
        # and model_fields_set contains the field
        if self.suburb is None and "suburb" in self.model_fields_set:
            _dict["suburb"] = None

        # set to None if city (nullable) is None
        # and model_fields_set contains the field
        if self.city is None and "city" in self.model_fields_set:
            _dict["city"] = None

        # set to None if town (nullable) is None
        # and model_fields_set contains the field
        if self.town is None and "town" in self.model_fields_set:
            _dict["town"] = None

        # set to None if county (nullable) is None
        # and model_fields_set contains the field
        if self.county is None and "county" in self.model_fields_set:
            _dict["county"] = None

        # set to None if state_district (nullable) is None
        # and model_fields_set contains the field
        if self.state_district is None and "state_district" in self.model_fields_set:
            _dict["stateDistrict"] = None

        # set to None if state (nullable) is None
        # and model_fields_set contains the field
        if self.state is None and "state" in self.model_fields_set:
            _dict["state"] = None

        # set to None if postcode (nullable) is None
        # and model_fields_set contains the field
        if self.postcode is None and "postcode" in self.model_fields_set:
            _dict["postcode"] = None

        # set to None if country (nullable) is None
        # and model_fields_set contains the field
        if self.country is None and "country" in self.model_fields_set:
            _dict["country"] = None

        # set to None if country_code (nullable) is None
        # and model_fields_set contains the field
        if self.country_code is None and "country_code" in self.model_fields_set:
            _dict["countryCode"] = None

        # set to None if amenity (nullable) is None
        # and model_fields_set contains the field
        if self.amenity is None and "amenity" in self.model_fields_set:
            _dict["amenity"] = None

        # set to None if neighbourhood (nullable) is None
        # and model_fields_set contains the field
        if self.neighbourhood is None and "neighbourhood" in self.model_fields_set:
            _dict["neighbourhood"] = None

        # set to None if coordinates (nullable) is None
        # and model_fields_set contains the field
        if self.coordinates is None and "coordinates" in self.model_fields_set:
            _dict["coordinates"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Place from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "osmId": obj.get("osmId"),
                "road": obj.get("road"),
                "quarter": obj.get("quarter"),
                "suburb": obj.get("suburb"),
                "city": obj.get("city"),
                "town": obj.get("town"),
                "county": obj.get("county"),
                "stateDistrict": obj.get("stateDistrict"),
                "state": obj.get("state"),
                "postcode": obj.get("postcode"),
                "country": obj.get("country"),
                "countryCode": obj.get("countryCode"),
                "amenity": obj.get("amenity"),
                "neighbourhood": obj.get("neighbourhood"),
                "coordinates": (
                    Coordinate.from_dict(obj["coordinates"])
                    if obj.get("coordinates") is not None
                    else None
                ),
            }
        )
        return _obj



# coding: utf-8

"""
Perigon API

The Perigon API provides access to comprehensive news and web content data. To use the API, simply sign up for a Perigon Business Solutions account to obtain your API key. Your available features may vary based on your plan. See the Authentication section for details on how to use your API key.

The version of the OpenAPI document: 1.0.0
Contact: data@perigon.io
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing_extensions import Self

from perigon.models.image_holder import ImageHolder
from perigon.models.source_location import SourceLocation
from perigon.models.source_top_stat_holder import SourceTopStatHolder


class Source(BaseModel):
    """
    Source
    """  # noqa: E501

    id: Optional[StrictStr] = None
    domain: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    primary_record_id: Optional[StrictStr] = Field(
        default=None, alias="primaryRecordId"
    )
    updated_at: Optional[StrictStr] = Field(default=None, alias="updatedAt")
    alt_names: Optional[List[StrictStr]] = Field(default=None, alias="altNames")
    description: Optional[StrictStr] = None
    avg_monthly_posts: Optional[StrictInt] = Field(
        default=None, alias="avgMonthlyPosts"
    )
    paywall: Optional[StrictBool] = None
    location: Optional[SourceLocation] = None
    top_categories: Optional[List[SourceTopStatHolder]] = Field(
        default=None, alias="topCategories"
    )
    top_topics: Optional[List[SourceTopStatHolder]] = Field(
        default=None, alias="topTopics"
    )
    top_countries: Optional[List[SourceTopStatHolder]] = Field(
        default=None, alias="topCountries"
    )
    top_labels: Optional[List[SourceTopStatHolder]] = Field(
        default=None, alias="topLabels"
    )
    avg_bias_rating: Optional[StrictStr] = Field(default=None, alias="avgBiasRating")
    ad_fontes_bias_rating: Optional[StrictStr] = Field(
        default=None, alias="adFontesBiasRating"
    )
    all_sides_bias_rating: Optional[StrictStr] = Field(
        default=None, alias="allSidesBiasRating"
    )
    mbfc_bias_rating: Optional[StrictStr] = Field(default=None, alias="mbfcBiasRating")
    monthly_visits: Optional[StrictInt] = Field(default=None, alias="monthlyVisits")
    global_rank: Optional[StrictInt] = Field(default=None, alias="globalRank")
    logo_large: Optional[ImageHolder] = Field(default=None, alias="logoLarge")
    logo_fav_icon: Optional[ImageHolder] = Field(default=None, alias="logoFavIcon")
    logo_square: Optional[ImageHolder] = Field(default=None, alias="logoSquare")
    __properties: ClassVar[List[str]] = [
        "id",
        "domain",
        "name",
        "primaryRecordId",
        "updatedAt",
        "altNames",
        "description",
        "avgMonthlyPosts",
        "paywall",
        "location",
        "topCategories",
        "topTopics",
        "topCountries",
        "topLabels",
        "avgBiasRating",
        "adFontesBiasRating",
        "allSidesBiasRating",
        "mbfcBiasRating",
        "monthlyVisits",
        "globalRank",
        "logoLarge",
        "logoFavIcon",
        "logoSquare",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Source from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of location
        if self.location:
            _dict["location"] = self.location.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in top_categories (list)
        _items = []
        if self.top_categories:
            for _item_top_categories in self.top_categories:
                if _item_top_categories:
                    _items.append(_item_top_categories.to_dict())
            _dict["topCategories"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in top_topics (list)
        _items = []
        if self.top_topics:
            for _item_top_topics in self.top_topics:
                if _item_top_topics:
                    _items.append(_item_top_topics.to_dict())
            _dict["topTopics"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in top_countries (list)
        _items = []
        if self.top_countries:
            for _item_top_countries in self.top_countries:
                if _item_top_countries:
                    _items.append(_item_top_countries.to_dict())
            _dict["topCountries"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in top_labels (list)
        _items = []
        if self.top_labels:
            for _item_top_labels in self.top_labels:
                if _item_top_labels:
                    _items.append(_item_top_labels.to_dict())
            _dict["topLabels"] = _items
        # override the default output from pydantic by calling `to_dict()` of logo_large
        if self.logo_large:
            _dict["logoLarge"] = self.logo_large.to_dict()
        # override the default output from pydantic by calling `to_dict()` of logo_fav_icon
        if self.logo_fav_icon:
            _dict["logoFavIcon"] = self.logo_fav_icon.to_dict()
        # override the default output from pydantic by calling `to_dict()` of logo_square
        if self.logo_square:
            _dict["logoSquare"] = self.logo_square.to_dict()
        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict["id"] = None

        # set to None if domain (nullable) is None
        # and model_fields_set contains the field
        if self.domain is None and "domain" in self.model_fields_set:
            _dict["domain"] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict["name"] = None

        # set to None if primary_record_id (nullable) is None
        # and model_fields_set contains the field
        if (
            self.primary_record_id is None
            and "primary_record_id" in self.model_fields_set
        ):
            _dict["primaryRecordId"] = None

        # set to None if updated_at (nullable) is None
        # and model_fields_set contains the field
        if self.updated_at is None and "updated_at" in self.model_fields_set:
            _dict["updatedAt"] = None

        # set to None if alt_names (nullable) is None
        # and model_fields_set contains the field
        if self.alt_names is None and "alt_names" in self.model_fields_set:
            _dict["altNames"] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict["description"] = None

        # set to None if avg_monthly_posts (nullable) is None
        # and model_fields_set contains the field
        if (
            self.avg_monthly_posts is None
            and "avg_monthly_posts" in self.model_fields_set
        ):
            _dict["avgMonthlyPosts"] = None

        # set to None if paywall (nullable) is None
        # and model_fields_set contains the field
        if self.paywall is None and "paywall" in self.model_fields_set:
            _dict["paywall"] = None

        # set to None if location (nullable) is None
        # and model_fields_set contains the field
        if self.location is None and "location" in self.model_fields_set:
            _dict["location"] = None

        # set to None if top_categories (nullable) is None
        # and model_fields_set contains the field
        if self.top_categories is None and "top_categories" in self.model_fields_set:
            _dict["topCategories"] = None

        # set to None if top_topics (nullable) is None
        # and model_fields_set contains the field
        if self.top_topics is None and "top_topics" in self.model_fields_set:
            _dict["topTopics"] = None

        # set to None if top_countries (nullable) is None
        # and model_fields_set contains the field
        if self.top_countries is None and "top_countries" in self.model_fields_set:
            _dict["topCountries"] = None

        # set to None if top_labels (nullable) is None
        # and model_fields_set contains the field
        if self.top_labels is None and "top_labels" in self.model_fields_set:
            _dict["topLabels"] = None

        # set to None if avg_bias_rating (nullable) is None
        # and model_fields_set contains the field
        if self.avg_bias_rating is None and "avg_bias_rating" in self.model_fields_set:
            _dict["avgBiasRating"] = None

        # set to None if ad_fontes_bias_rating (nullable) is None
        # and model_fields_set contains the field
        if (
            self.ad_fontes_bias_rating is None
            and "ad_fontes_bias_rating" in self.model_fields_set
        ):
            _dict["adFontesBiasRating"] = None

        # set to None if all_sides_bias_rating (nullable) is None
        # and model_fields_set contains the field
        if (
            self.all_sides_bias_rating is None
            and "all_sides_bias_rating" in self.model_fields_set
        ):
            _dict["allSidesBiasRating"] = None

        # set to None if mbfc_bias_rating (nullable) is None
        # and model_fields_set contains the field
        if (
            self.mbfc_bias_rating is None
            and "mbfc_bias_rating" in self.model_fields_set
        ):
            _dict["mbfcBiasRating"] = None

        # set to None if monthly_visits (nullable) is None
        # and model_fields_set contains the field
        if self.monthly_visits is None and "monthly_visits" in self.model_fields_set:
            _dict["monthlyVisits"] = None

        # set to None if global_rank (nullable) is None
        # and model_fields_set contains the field
        if self.global_rank is None and "global_rank" in self.model_fields_set:
            _dict["globalRank"] = None

        # set to None if logo_large (nullable) is None
        # and model_fields_set contains the field
        if self.logo_large is None and "logo_large" in self.model_fields_set:
            _dict["logoLarge"] = None

        # set to None if logo_fav_icon (nullable) is None
        # and model_fields_set contains the field
        if self.logo_fav_icon is None and "logo_fav_icon" in self.model_fields_set:
            _dict["logoFavIcon"] = None

        # set to None if logo_square (nullable) is None
        # and model_fields_set contains the field
        if self.logo_square is None and "logo_square" in self.model_fields_set:
            _dict["logoSquare"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Source from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "id": obj.get("id"),
                "domain": obj.get("domain"),
                "name": obj.get("name"),
                "primaryRecordId": obj.get("primaryRecordId"),
                "updatedAt": obj.get("updatedAt"),
                "altNames": obj.get("altNames"),
                "description": obj.get("description"),
                "avgMonthlyPosts": obj.get("avgMonthlyPosts"),
                "paywall": obj.get("paywall"),
                "location": (
                    SourceLocation.from_dict(obj["location"])
                    if obj.get("location") is not None
                    else None
                ),
                "topCategories": (
                    [
                        SourceTopStatHolder.from_dict(_item)
                        for _item in obj["topCategories"]
                    ]
                    if obj.get("topCategories") is not None
                    else None
                ),
                "topTopics": (
                    [SourceTopStatHolder.from_dict(_item) for _item in obj["topTopics"]]
                    if obj.get("topTopics") is not None
                    else None
                ),
                "topCountries": (
                    [
                        SourceTopStatHolder.from_dict(_item)
                        for _item in obj["topCountries"]
                    ]
                    if obj.get("topCountries") is not None
                    else None
                ),
                "topLabels": (
                    [SourceTopStatHolder.from_dict(_item) for _item in obj["topLabels"]]
                    if obj.get("topLabels") is not None
                    else None
                ),
                "avgBiasRating": obj.get("avgBiasRating"),
                "adFontesBiasRating": obj.get("adFontesBiasRating"),
                "allSidesBiasRating": obj.get("allSidesBiasRating"),
                "mbfcBiasRating": obj.get("mbfcBiasRating"),
                "monthlyVisits": obj.get("monthlyVisits"),
                "globalRank": obj.get("globalRank"),
                "logoLarge": (
                    ImageHolder.from_dict(obj["logoLarge"])
                    if obj.get("logoLarge") is not None
                    else None
                ),
                "logoFavIcon": (
                    ImageHolder.from_dict(obj["logoFavIcon"])
                    if obj.get("logoFavIcon") is not None
                    else None
                ),
                "logoSquare": (
                    ImageHolder.from_dict(obj["logoSquare"])
                    if obj.get("logoSquare") is not None
                    else None
                ),
            }
        )
        return _obj



# coding: utf-8

"""
Perigon API

The Perigon API provides access to comprehensive news and web content data. To use the API, simply sign up for a Perigon Business Solutions account to obtain your API key. Your available features may vary based on your plan. See the Authentication section for details on how to use your API key.

The version of the OpenAPI document: 1.0.0
Contact: data@perigon.io
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing_extensions import Self

from perigon.models.coordinate_filter import CoordinateFilter


class ArticleSearchFilter(BaseModel):
    """
    Complex filter structure for article searches that supports nested logical operations (AND, OR, NOT) and multiple filtering criteria.
    """  # noqa: E501

    article_id: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter by specific article identifiers. Accepts either a single ID or an array of IDs. Returns only articles matching these IDs.",
        alias="articleId",
    )
    cluster_id: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter by specific story identifiers. Accepts either a single ID or an array of IDs. Returns only articles belonging to these stories.",
        alias="clusterId",
    )
    source: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter articles by specific publisher domains or subdomains. Accepts either a single domain or an array of domains. Multiple values create an OR filter.",
    )
    exclude_source: Optional[List[StrictStr]] = Field(
        default=None,
        description="Exclude articles from specific publisher domains or subdomains. Accepts either a single domain or an array of domains. Multiple values create an AND-exclude filter.",
        alias="excludeSource",
    )
    source_group: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter articles using Perigon's curated publisher bundles (e.g., top100, top25tech). Accepts either a single source group or an array. Multiple values create an OR filter to include articles from any of the specified bundles.",
        alias="sourceGroup",
    )
    language: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter articles by their language using ISO-639 two-letter codes in lowercase (e.g., en, es, fr). Accepts either a single language code or an array. Multiple values create an OR filter.",
    )
    exclude_language: Optional[List[StrictStr]] = Field(
        default=None,
        description="Exclude articles in specific languages using ISO-639 two-letter codes in lowercase. Accepts either a single language code or an array. Multiple values create an AND-exclude filter.",
        alias="excludeLanguage",
    )
    label: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter articles by editorial labels such as Opinion, Paid-news, Non-news, Fact Check, or Press Release. View our docs for an exhaustive list of labels. Accepts either a single label or an array. Multiple values create an OR filter.",
    )
    exclude_label: Optional[List[StrictStr]] = Field(
        default=None,
        description="Exclude articles with specific editorial labels. Accepts either a single label or an array. Multiple values create an AND-exclude filter, removing all content with any of these labels.",
        alias="excludeLabel",
    )
    taxonomy: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter by Google Content Categories. Must pass the full hierarchical path of the category. Accepts either a single path or an array. Example: taxonomy=/Finance/Banking/Other,/Finance/Investing/Funds. Multiple values create an OR filter.",
    )
    category: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter by broad content categories such as Politics, Tech, Sports, Business, or Finance. Accepts either a single category or an array. Use none to find uncategorized articles. Multiple values create an OR filter.",
    )
    topic: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter by specific topics such as Markets, Crime, Cryptocurrency, or College Sports. Accepts either a single topic or an array. Topics are more granular than categories, and articles can have multiple topics. Multiple values create an OR filter.",
    )
    exclude_topic: Optional[List[StrictStr]] = Field(
        default=None,
        description="Exclude articles with specific topics. Accepts either a single topic or an array. Multiple values create an AND-exclude filter, removing all content with any of these topics.",
        alias="excludeTopic",
    )
    country: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter articles by countries they mention using two-letter country codes in lowercase (e.g., us, gb, jp). Accepts either a single country code or an array. Multiple values create an OR filter. See documentation for supported country codes.",
    )
    exclude_country: Optional[List[StrictStr]] = Field(
        default=None,
        description="Exclude articles from specific countries using two-letter country codes in lowercase. Accepts either a single country code or an array. Multiple values create an AND-exclude filter. See documentation for supported country codes.",
        alias="excludeCountry",
    )
    locations_country: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter articles where specified countries play a central role in the content, not just mentioned. Uses two-letter country codes in lowercase. Accepts either a single country code or an array. Multiple values create an OR filter. See documentation for supported country codes.",
        alias="locationsCountry",
    )
    exclude_locations_country: Optional[List[StrictStr]] = Field(
        default=None,
        description="Exclude articles where specified countries play a central role in the content. Accepts either a single country code or an array. Multiple values create an AND-exclude filter, removing articles focused on any of these countries. See documentation for supported country codes.",
        alias="excludeLocationsCountry",
    )
    state: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter articles where specified states play a central role in the content. Accepts either a single state code or an array. Multiple values create an OR filter. Uses two-letter state codes in lowercase. See documentation for supported state codes.",
    )
    exclude_state: Optional[List[StrictStr]] = Field(
        default=None,
        description="Exclude articles where specified states play a central role. Accepts either a single state code or an array. Multiple values create an AND-exclude filter, removing articles focused on any of these states. See documentation for supported state codes.",
        alias="excludeState",
    )
    county: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter articles that mention or are related to specific counties. Accepts either a single county name or an array. Multiple values create an OR filter. County names typically include the word 'County' (e.g., Los Angeles County).",
    )
    exclude_county: Optional[List[StrictStr]] = Field(
        default=None,
        description="Exclude articles that mention or are related to specific counties. Accepts either a single county name or an array. Multiple values create an AND-exclude filter. County names should match the format in article metadata (e.g., Los Angeles County, Cook County).",
        alias="excludeCounty",
    )
    city: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter articles that mention or are related to specific cities. Accepts either a single city name or an array. Multiple values create an OR filter.",
    )
    exclude_city: Optional[List[StrictStr]] = Field(
        default=None,
        description="Exclude articles that mention or are related to specific cities. Accepts either a single city name or an array. Multiple values create an AND-exclude filter.",
        alias="excludeCity",
    )
    source_country: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter for articles from publishers based in specific countries. Accepts either a single country code or an array. Uses two-letter country codes in lowercase (e.g., us, gb). See documentation for supported country codes.",
        alias="sourceCountry",
    )
    source_state: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter for articles from publishers based in specific states or regions. Accepts either a single state code or an array. Uses two-letter state codes in lowercase. See documentation for supported state codes.",
        alias="sourceState",
    )
    source_county: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter for articles from publishers based in specific counties. Accepts either a single county name or an array. Multiple values create an OR filter.",
        alias="sourceCounty",
    )
    source_city: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter for articles from publishers based in specific cities. Accepts either a single city name or an array. Multiple values create an OR filter.",
        alias="sourceCity",
    )
    coordinates: Optional[CoordinateFilter] = None
    source_coordinates: Optional[CoordinateFilter] = Field(
        default=None, alias="sourceCoordinates"
    )
    company_id: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter articles by company identifiers. Accepts either a single ID or an array. Multiple values create an OR filter. For a complete list of tracked companies and their IDs, refer to the /companies endpoint.",
        alias="companyId",
    )
    exclude_company_id: Optional[List[StrictStr]] = Field(
        default=None,
        description="Exclude articles mentioning companies with specific identifiers. Accepts either a single ID or an array. Multiple values create an AND-exclude filter. For a complete list of tracked companies and their IDs, refer to the /companies endpoint.",
        alias="excludeCompanyId",
    )
    company_domain: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter articles by company domains (e.g., apple.com). Accepts either a single domain or an array. Multiple values create an OR filter. For a complete list of tracked companies and their domains, refer to the /companies endpoint.",
        alias="companyDomain",
    )
    exclude_company_domain: Optional[List[StrictStr]] = Field(
        default=None,
        description="Exclude articles related to companies with specific domains. Accepts either a single domain or an array. Multiple values create an AND-exclude filter. For a complete list of tracked companies and their domains, refer to the /companies endpoint.",
        alias="excludeCompanyDomain",
    )
    company_symbol: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter articles by company stock symbols (e.g., AAPL, MSFT). Accepts either a single symbol or an array. Multiple values create an OR filter. For a complete list of tracked companies and their symbols, refer to the /companies endpoint.",
        alias="companySymbol",
    )
    exclude_company_symbol: Optional[List[StrictStr]] = Field(
        default=None,
        description="Exclude articles related to companies with specific stock symbols. Accepts either a single symbol or an array. Multiple values create an AND-exclude filter. For a complete list of tracked companies and their symbols, refer to the /companies endpoint.",
        alias="excludeCompanySymbol",
    )
    company_name: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter articles by company name mentions. Accepts either a single name or an array. Performs exact matching on company names. Multiple values create an OR filter. For a complete list of tracked companies and their names, refer to the /companies endpoint.",
        alias="companyName",
    )
    person_wikidata_id: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter articles by Wikidata IDs of mentioned people. Accepts either a single ID or an array. Multiple values create an OR filter. For a complete list of tracked individuals and their Wikidata IDs, refer to the /people endpoint.",
        alias="personWikidataId",
    )
    exclude_person_wikidata_id: Optional[List[StrictStr]] = Field(
        default=None,
        description="Exclude articles mentioning people with specific Wikidata IDs. Accepts either a single ID or an array. Multiple values create an AND-exclude filter. For a complete list of tracked individuals and their Wikidata IDs, refer to the /people endpoint.",
        alias="excludePersonWikidataId",
    )
    person_name: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter articles by exact person name matches. Accepts either a single name or an array. Does not support Boolean operators or wildcards. Multiple values create an OR filter. For a complete list of tracked individuals and their names, refer to the /people endpoint.",
        alias="personName",
    )
    exclude_person_name: Optional[List[StrictStr]] = Field(
        default=None,
        description="Exclude articles mentioning specific people by name. Accepts either a single name or an array. Multiple values create an AND-exclude filter. For a complete list of tracked individuals and their names, refer to the /people endpoint.",
        alias="excludePersonName",
    )
    var_and: Optional[List[ArticleSearchFilter]] = Field(
        default=None,
        description="Adds additional AND filter objects. These objects must be of the same type as the original filter object and will be combined with the existing filter using the AND logical operator.",
        alias="AND",
    )
    var_or: Optional[List[ArticleSearchFilter]] = Field(
        default=None,
        description="Adds additional OR filter objects. These objects must be of the same type as the original filter object and will be combined with the existing filter using the OR logical operator.",
        alias="OR",
    )
    var_not: Optional[List[ArticleSearchFilter]] = Field(
        default=None,
        description="A filter object for logical NOT operations",
        alias="NOT",
    )
    __properties: ClassVar[List[str]] = [
        "articleId",
        "clusterId",
        "source",
        "excludeSource",
        "sourceGroup",
        "language",
        "excludeLanguage",
        "label",
        "excludeLabel",
        "taxonomy",
        "category",
        "topic",
        "excludeTopic",
        "country",
        "excludeCountry",
        "locationsCountry",
        "excludeLocationsCountry",
        "state",
        "excludeState",
        "county",
        "excludeCounty",
        "city",
        "excludeCity",
        "sourceCountry",
        "sourceState",
        "sourceCounty",
        "sourceCity",
        "coordinates",
        "sourceCoordinates",
        "companyId",
        "excludeCompanyId",
        "companyDomain",
        "excludeCompanyDomain",
        "companySymbol",
        "excludeCompanySymbol",
        "companyName",
        "personWikidataId",
        "excludePersonWikidataId",
        "personName",
        "excludePersonName",
        "AND",
        "OR",
        "NOT",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ArticleSearchFilter from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of coordinates
        if self.coordinates:
            _dict["coordinates"] = self.coordinates.to_dict()
        # override the default output from pydantic by calling `to_dict()` of source_coordinates
        if self.source_coordinates:
            _dict["sourceCoordinates"] = self.source_coordinates.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in var_and (list)
        _items = []
        if self.var_and:
            for _item_var_and in self.var_and:
                if _item_var_and:
                    _items.append(_item_var_and.to_dict())
            _dict["AND"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in var_or (list)
        _items = []
        if self.var_or:
            for _item_var_or in self.var_or:
                if _item_var_or:
                    _items.append(_item_var_or.to_dict())
            _dict["OR"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in var_not (list)
        _items = []
        if self.var_not:
            for _item_var_not in self.var_not:
                if _item_var_not:
                    _items.append(_item_var_not.to_dict())
            _dict["NOT"] = _items
        # set to None if article_id (nullable) is None
        # and model_fields_set contains the field
        if self.article_id is None and "article_id" in self.model_fields_set:
            _dict["articleId"] = None

        # set to None if cluster_id (nullable) is None
        # and model_fields_set contains the field
        if self.cluster_id is None and "cluster_id" in self.model_fields_set:
            _dict["clusterId"] = None

        # set to None if source (nullable) is None
        # and model_fields_set contains the field
        if self.source is None and "source" in self.model_fields_set:
            _dict["source"] = None

        # set to None if exclude_source (nullable) is None
        # and model_fields_set contains the field
        if self.exclude_source is None and "exclude_source" in self.model_fields_set:
            _dict["excludeSource"] = None

        # set to None if source_group (nullable) is None
        # and model_fields_set contains the field
        if self.source_group is None and "source_group" in self.model_fields_set:
            _dict["sourceGroup"] = None

        # set to None if language (nullable) is None
        # and model_fields_set contains the field
        if self.language is None and "language" in self.model_fields_set:
            _dict["language"] = None

        # set to None if exclude_language (nullable) is None
        # and model_fields_set contains the field
        if (
            self.exclude_language is None
            and "exclude_language" in self.model_fields_set
        ):
            _dict["excludeLanguage"] = None

        # set to None if label (nullable) is None
        # and model_fields_set contains the field
        if self.label is None and "label" in self.model_fields_set:
            _dict["label"] = None

        # set to None if exclude_label (nullable) is None
        # and model_fields_set contains the field
        if self.exclude_label is None and "exclude_label" in self.model_fields_set:
            _dict["excludeLabel"] = None

        # set to None if taxonomy (nullable) is None
        # and model_fields_set contains the field
        if self.taxonomy is None and "taxonomy" in self.model_fields_set:
            _dict["taxonomy"] = None

        # set to None if category (nullable) is None
        # and model_fields_set contains the field
        if self.category is None and "category" in self.model_fields_set:
            _dict["category"] = None

        # set to None if topic (nullable) is None
        # and model_fields_set contains the field
        if self.topic is None and "topic" in self.model_fields_set:
            _dict["topic"] = None

        # set to None if exclude_topic (nullable) is None
        # and model_fields_set contains the field
        if self.exclude_topic is None and "exclude_topic" in self.model_fields_set:
            _dict["excludeTopic"] = None

        # set to None if country (nullable) is None
        # and model_fields_set contains the field
        if self.country is None and "country" in self.model_fields_set:
            _dict["country"] = None

        # set to None if exclude_country (nullable) is None
        # and model_fields_set contains the field
        if self.exclude_country is None and "exclude_country" in self.model_fields_set:
            _dict["excludeCountry"] = None

        # set to None if locations_country (nullable) is None
        # and model_fields_set contains the field
        if (
            self.locations_country is None
            and "locations_country" in self.model_fields_set
        ):
            _dict["locationsCountry"] = None

        # set to None if exclude_locations_country (nullable) is None
        # and model_fields_set contains the field
        if (
            self.exclude_locations_country is None
            and "exclude_locations_country" in self.model_fields_set
        ):
            _dict["excludeLocationsCountry"] = None

        # set to None if state (nullable) is None
        # and model_fields_set contains the field
        if self.state is None and "state" in self.model_fields_set:
            _dict["state"] = None

        # set to None if exclude_state (nullable) is None
        # and model_fields_set contains the field
        if self.exclude_state is None and "exclude_state" in self.model_fields_set:
            _dict["excludeState"] = None

        # set to None if county (nullable) is None
        # and model_fields_set contains the field
        if self.county is None and "county" in self.model_fields_set:
            _dict["county"] = None

        # set to None if exclude_county (nullable) is None
        # and model_fields_set contains the field
        if self.exclude_county is None and "exclude_county" in self.model_fields_set:
            _dict["excludeCounty"] = None

        # set to None if city (nullable) is None
        # and model_fields_set contains the field
        if self.city is None and "city" in self.model_fields_set:
            _dict["city"] = None

        # set to None if exclude_city (nullable) is None
        # and model_fields_set contains the field
        if self.exclude_city is None and "exclude_city" in self.model_fields_set:
            _dict["excludeCity"] = None

        # set to None if source_country (nullable) is None
        # and model_fields_set contains the field
        if self.source_country is None and "source_country" in self.model_fields_set:
            _dict["sourceCountry"] = None

        # set to None if source_state (nullable) is None
        # and model_fields_set contains the field
        if self.source_state is None and "source_state" in self.model_fields_set:
            _dict["sourceState"] = None

        # set to None if source_county (nullable) is None
        # and model_fields_set contains the field
        if self.source_county is None and "source_county" in self.model_fields_set:
            _dict["sourceCounty"] = None

        # set to None if source_city (nullable) is None
        # and model_fields_set contains the field
        if self.source_city is None and "source_city" in self.model_fields_set:
            _dict["sourceCity"] = None

        # set to None if coordinates (nullable) is None
        # and model_fields_set contains the field
        if self.coordinates is None and "coordinates" in self.model_fields_set:
            _dict["coordinates"] = None

        # set to None if source_coordinates (nullable) is None
        # and model_fields_set contains the field
        if (
            self.source_coordinates is None
            and "source_coordinates" in self.model_fields_set
        ):
            _dict["sourceCoordinates"] = None

        # set to None if company_id (nullable) is None
        # and model_fields_set contains the field
        if self.company_id is None and "company_id" in self.model_fields_set:
            _dict["companyId"] = None

        # set to None if exclude_company_id (nullable) is None
        # and model_fields_set contains the field
        if (
            self.exclude_company_id is None
            and "exclude_company_id" in self.model_fields_set
        ):
            _dict["excludeCompanyId"] = None

        # set to None if company_domain (nullable) is None
        # and model_fields_set contains the field
        if self.company_domain is None and "company_domain" in self.model_fields_set:
            _dict["companyDomain"] = None

        # set to None if exclude_company_domain (nullable) is None
        # and model_fields_set contains the field
        if (
            self.exclude_company_domain is None
            and "exclude_company_domain" in self.model_fields_set
        ):
            _dict["excludeCompanyDomain"] = None

        # set to None if company_symbol (nullable) is None
        # and model_fields_set contains the field
        if self.company_symbol is None and "company_symbol" in self.model_fields_set:
            _dict["companySymbol"] = None

        # set to None if exclude_company_symbol (nullable) is None
        # and model_fields_set contains the field
        if (
            self.exclude_company_symbol is None
            and "exclude_company_symbol" in self.model_fields_set
        ):
            _dict["excludeCompanySymbol"] = None

        # set to None if company_name (nullable) is None
        # and model_fields_set contains the field
        if self.company_name is None and "company_name" in self.model_fields_set:
            _dict["companyName"] = None

        # set to None if person_wikidata_id (nullable) is None
        # and model_fields_set contains the field
        if (
            self.person_wikidata_id is None
            and "person_wikidata_id" in self.model_fields_set
        ):
            _dict["personWikidataId"] = None

        # set to None if exclude_person_wikidata_id (nullable) is None
        # and model_fields_set contains the field
        if (
            self.exclude_person_wikidata_id is None
            and "exclude_person_wikidata_id" in self.model_fields_set
        ):
            _dict["excludePersonWikidataId"] = None

        # set to None if person_name (nullable) is None
        # and model_fields_set contains the field
        if self.person_name is None and "person_name" in self.model_fields_set:
            _dict["personName"] = None

        # set to None if exclude_person_name (nullable) is None
        # and model_fields_set contains the field
        if (
            self.exclude_person_name is None
            and "exclude_person_name" in self.model_fields_set
        ):
            _dict["excludePersonName"] = None

        # set to None if var_and (nullable) is None
        # and model_fields_set contains the field
        if self.var_and is None and "var_and" in self.model_fields_set:
            _dict["AND"] = None

        # set to None if var_or (nullable) is None
        # and model_fields_set contains the field
        if self.var_or is None and "var_or" in self.model_fields_set:
            _dict["OR"] = None

        # set to None if var_not (nullable) is None
        # and model_fields_set contains the field
        if self.var_not is None and "var_not" in self.model_fields_set:
            _dict["NOT"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ArticleSearchFilter from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "articleId": obj.get("articleId"),
                "clusterId": obj.get("clusterId"),
                "source": obj.get("source"),
                "excludeSource": obj.get("excludeSource"),
                "sourceGroup": obj.get("sourceGroup"),
                "language": obj.get("language"),
                "excludeLanguage": obj.get("excludeLanguage"),
                "label": obj.get("label"),
                "excludeLabel": obj.get("excludeLabel"),
                "taxonomy": obj.get("taxonomy"),
                "category": obj.get("category"),
                "topic": obj.get("topic"),
                "excludeTopic": obj.get("excludeTopic"),
                "country": obj.get("country"),
                "excludeCountry": obj.get("excludeCountry"),
                "locationsCountry": obj.get("locationsCountry"),
                "excludeLocationsCountry": obj.get("excludeLocationsCountry"),
                "state": obj.get("state"),
                "excludeState": obj.get("excludeState"),
                "county": obj.get("county"),
                "excludeCounty": obj.get("excludeCounty"),
                "city": obj.get("city"),
                "excludeCity": obj.get("excludeCity"),
                "sourceCountry": obj.get("sourceCountry"),
                "sourceState": obj.get("sourceState"),
                "sourceCounty": obj.get("sourceCounty"),
                "sourceCity": obj.get("sourceCity"),
                "coordinates": (
                    CoordinateFilter.from_dict(obj["coordinates"])
                    if obj.get("coordinates") is not None
                    else None
                ),
                "sourceCoordinates": (
                    CoordinateFilter.from_dict(obj["sourceCoordinates"])
                    if obj.get("sourceCoordinates") is not None
                    else None
                ),
                "companyId": obj.get("companyId"),
                "excludeCompanyId": obj.get("excludeCompanyId"),
                "companyDomain": obj.get("companyDomain"),
                "excludeCompanyDomain": obj.get("excludeCompanyDomain"),
                "companySymbol": obj.get("companySymbol"),
                "excludeCompanySymbol": obj.get("excludeCompanySymbol"),
                "companyName": obj.get("companyName"),
                "personWikidataId": obj.get("personWikidataId"),
                "excludePersonWikidataId": obj.get("excludePersonWikidataId"),
                "personName": obj.get("personName"),
                "excludePersonName": obj.get("excludePersonName"),
                "AND": (
                    [ArticleSearchFilter.from_dict(_item) for _item in obj["AND"]]
                    if obj.get("AND") is not None
                    else None
                ),
                "OR": (
                    [ArticleSearchFilter.from_dict(_item) for _item in obj["OR"]]
                    if obj.get("OR") is not None
                    else None
                ),
                "NOT": (
                    [ArticleSearchFilter.from_dict(_item) for _item in obj["NOT"]]
                    if obj.get("NOT") is not None
                    else None
                ),
            }
        )
        return _obj


# TODO: Rewrite to not use raise_errors
ArticleSearchFilter.model_rebuild(raise_errors=False)



# coding: utf-8

"""
Perigon API

The Perigon API provides access to comprehensive news and web content data. To use the API, simply sign up for a Perigon Business Solutions account to obtain your API key. Your available features may vary based on your plan. See the Authentication section for details on how to use your API key.

The version of the OpenAPI document: 1.0.0
Contact: data@perigon.io
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing_extensions import Self

from perigon.models.location_holder import LocationHolder
from perigon.models.name_count import NameCount


class Journalist(BaseModel):
    """
    Journalist
    """  # noqa: E501

    id: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    full_name: Optional[StrictStr] = Field(default=None, alias="fullName")
    headline: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    title: Optional[StrictStr] = None
    locations: Optional[List[LocationHolder]] = None
    updated_at: Optional[StrictStr] = Field(default=None, alias="updatedAt")
    top_topics: Optional[List[NameCount]] = Field(default=None, alias="topTopics")
    top_sources: Optional[List[NameCount]] = Field(default=None, alias="topSources")
    top_categories: Optional[List[NameCount]] = Field(
        default=None, alias="topCategories"
    )
    top_labels: Optional[List[NameCount]] = Field(default=None, alias="topLabels")
    top_countries: Optional[List[NameCount]] = Field(default=None, alias="topCountries")
    avg_monthly_posts: Optional[StrictInt] = Field(
        default=None, alias="avgMonthlyPosts"
    )
    twitter_handle: Optional[StrictStr] = Field(default=None, alias="twitterHandle")
    twitter_bio: Optional[StrictStr] = Field(default=None, alias="twitterBio")
    image_url: Optional[StrictStr] = Field(default=None, alias="imageUrl")
    linkedin_url: Optional[StrictStr] = Field(default=None, alias="linkedinUrl")
    linkedin_connections: Optional[StrictInt] = Field(
        default=None, alias="linkedinConnections"
    )
    linkedin_followers: Optional[StrictInt] = Field(
        default=None, alias="linkedinFollowers"
    )
    facebook_url: Optional[StrictStr] = Field(default=None, alias="facebookUrl")
    instagram_url: Optional[StrictStr] = Field(default=None, alias="instagramUrl")
    website_url: Optional[StrictStr] = Field(default=None, alias="websiteUrl")
    blog_url: Optional[StrictStr] = Field(default=None, alias="blogUrl")
    tumblr_url: Optional[StrictStr] = Field(default=None, alias="tumblrUrl")
    youtube_url: Optional[StrictStr] = Field(default=None, alias="youtubeUrl")
    __properties: ClassVar[List[str]] = [
        "id",
        "name",
        "fullName",
        "headline",
        "description",
        "title",
        "locations",
        "updatedAt",
        "topTopics",
        "topSources",
        "topCategories",
        "topLabels",
        "topCountries",
        "avgMonthlyPosts",
        "twitterHandle",
        "twitterBio",
        "imageUrl",
        "linkedinUrl",
        "linkedinConnections",
        "linkedinFollowers",
        "facebookUrl",
        "instagramUrl",
        "websiteUrl",
        "blogUrl",
        "tumblrUrl",
        "youtubeUrl",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Journalist from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in locations (list)
        _items = []
        if self.locations:
            for _item_locations in self.locations:
                if _item_locations:
                    _items.append(_item_locations.to_dict())
            _dict["locations"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in top_topics (list)
        _items = []
        if self.top_topics:
            for _item_top_topics in self.top_topics:
                if _item_top_topics:
                    _items.append(_item_top_topics.to_dict())
            _dict["topTopics"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in top_sources (list)
        _items = []
        if self.top_sources:
            for _item_top_sources in self.top_sources:
                if _item_top_sources:
                    _items.append(_item_top_sources.to_dict())
            _dict["topSources"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in top_categories (list)
        _items = []
        if self.top_categories:
            for _item_top_categories in self.top_categories:
                if _item_top_categories:
                    _items.append(_item_top_categories.to_dict())
            _dict["topCategories"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in top_labels (list)
        _items = []
        if self.top_labels:
            for _item_top_labels in self.top_labels:
                if _item_top_labels:
                    _items.append(_item_top_labels.to_dict())
            _dict["topLabels"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in top_countries (list)
        _items = []
        if self.top_countries:
            for _item_top_countries in self.top_countries:
                if _item_top_countries:
                    _items.append(_item_top_countries.to_dict())
            _dict["topCountries"] = _items
        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict["id"] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict["name"] = None

        # set to None if full_name (nullable) is None
        # and model_fields_set contains the field
        if self.full_name is None and "full_name" in self.model_fields_set:
            _dict["fullName"] = None

        # set to None if headline (nullable) is None
        # and model_fields_set contains the field
        if self.headline is None and "headline" in self.model_fields_set:
            _dict["headline"] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict["description"] = None

        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict["title"] = None

        # set to None if locations (nullable) is None
        # and model_fields_set contains the field
        if self.locations is None and "locations" in self.model_fields_set:
            _dict["locations"] = None

        # set to None if updated_at (nullable) is None
        # and model_fields_set contains the field
        if self.updated_at is None and "updated_at" in self.model_fields_set:
            _dict["updatedAt"] = None

        # set to None if top_topics (nullable) is None
        # and model_fields_set contains the field
        if self.top_topics is None and "top_topics" in self.model_fields_set:
            _dict["topTopics"] = None

        # set to None if top_sources (nullable) is None
        # and model_fields_set contains the field
        if self.top_sources is None and "top_sources" in self.model_fields_set:
            _dict["topSources"] = None

        # set to None if top_categories (nullable) is None
        # and model_fields_set contains the field
        if self.top_categories is None and "top_categories" in self.model_fields_set:
            _dict["topCategories"] = None

        # set to None if top_labels (nullable) is None
        # and model_fields_set contains the field
        if self.top_labels is None and "top_labels" in self.model_fields_set:
            _dict["topLabels"] = None

        # set to None if top_countries (nullable) is None
        # and model_fields_set contains the field
        if self.top_countries is None and "top_countries" in self.model_fields_set:
            _dict["topCountries"] = None

        # set to None if avg_monthly_posts (nullable) is None
        # and model_fields_set contains the field
        if (
            self.avg_monthly_posts is None
            and "avg_monthly_posts" in self.model_fields_set
        ):
            _dict["avgMonthlyPosts"] = None

        # set to None if twitter_handle (nullable) is None
        # and model_fields_set contains the field
        if self.twitter_handle is None and "twitter_handle" in self.model_fields_set:
            _dict["twitterHandle"] = None

        # set to None if twitter_bio (nullable) is None
        # and model_fields_set contains the field
        if self.twitter_bio is None and "twitter_bio" in self.model_fields_set:
            _dict["twitterBio"] = None

        # set to None if image_url (nullable) is None
        # and model_fields_set contains the field
        if self.image_url is None and "image_url" in self.model_fields_set:
            _dict["imageUrl"] = None

        # set to None if linkedin_url (nullable) is None
        # and model_fields_set contains the field
        if self.linkedin_url is None and "linkedin_url" in self.model_fields_set:
            _dict["linkedinUrl"] = None

        # set to None if linkedin_connections (nullable) is None
        # and model_fields_set contains the field
        if (
            self.linkedin_connections is None
            and "linkedin_connections" in self.model_fields_set
        ):
            _dict["linkedinConnections"] = None

        # set to None if linkedin_followers (nullable) is None
        # and model_fields_set contains the field
        if (
            self.linkedin_followers is None
            and "linkedin_followers" in self.model_fields_set
        ):
            _dict["linkedinFollowers"] = None

        # set to None if facebook_url (nullable) is None
        # and model_fields_set contains the field
        if self.facebook_url is None and "facebook_url" in self.model_fields_set:
            _dict["facebookUrl"] = None

        # set to None if instagram_url (nullable) is None
        # and model_fields_set contains the field
        if self.instagram_url is None and "instagram_url" in self.model_fields_set:
            _dict["instagramUrl"] = None

        # set to None if website_url (nullable) is None
        # and model_fields_set contains the field
        if self.website_url is None and "website_url" in self.model_fields_set:
            _dict["websiteUrl"] = None

        # set to None if blog_url (nullable) is None
        # and model_fields_set contains the field
        if self.blog_url is None and "blog_url" in self.model_fields_set:
            _dict["blogUrl"] = None

        # set to None if tumblr_url (nullable) is None
        # and model_fields_set contains the field
        if self.tumblr_url is None and "tumblr_url" in self.model_fields_set:
            _dict["tumblrUrl"] = None

        # set to None if youtube_url (nullable) is None
        # and model_fields_set contains the field
        if self.youtube_url is None and "youtube_url" in self.model_fields_set:
            _dict["youtubeUrl"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Journalist from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "id": obj.get("id"),
                "name": obj.get("name"),
                "fullName": obj.get("fullName"),
                "headline": obj.get("headline"),
                "description": obj.get("description"),
                "title": obj.get("title"),
                "locations": (
                    [LocationHolder.from_dict(_item) for _item in obj["locations"]]
                    if obj.get("locations") is not None
                    else None
                ),
                "updatedAt": obj.get("updatedAt"),
                "topTopics": (
                    [NameCount.from_dict(_item) for _item in obj["topTopics"]]
                    if obj.get("topTopics") is not None
                    else None
                ),
                "topSources": (
                    [NameCount.from_dict(_item) for _item in obj["topSources"]]
                    if obj.get("topSources") is not None
                    else None
                ),
                "topCategories": (
                    [NameCount.from_dict(_item) for _item in obj["topCategories"]]
                    if obj.get("topCategories") is not None
                    else None
                ),
                "topLabels": (
                    [NameCount.from_dict(_item) for _item in obj["topLabels"]]
                    if obj.get("topLabels") is not None
                    else None
                ),
                "topCountries": (
                    [NameCount.from_dict(_item) for _item in obj["topCountries"]]
                    if obj.get("topCountries") is not None
                    else None
                ),
                "avgMonthlyPosts": obj.get("avgMonthlyPosts"),
                "twitterHandle": obj.get("twitterHandle"),
                "twitterBio": obj.get("twitterBio"),
                "imageUrl": obj.get("imageUrl"),
                "linkedinUrl": obj.get("linkedinUrl"),
                "linkedinConnections": obj.get("linkedinConnections"),
                "linkedinFollowers": obj.get("linkedinFollowers"),
                "facebookUrl": obj.get("facebookUrl"),
                "instagramUrl": obj.get("instagramUrl"),
                "websiteUrl": obj.get("websiteUrl"),
                "blogUrl": obj.get("blogUrl"),
                "tumblrUrl": obj.get("tumblrUrl"),
                "youtubeUrl": obj.get("youtubeUrl"),
            }
        )
        return _obj



# coding: utf-8

"""
Perigon API

The Perigon API provides access to comprehensive news and web content data. To use the API, simply sign up for a Perigon Business Solutions account to obtain your API key. Your available features may vary based on your plan. See the Authentication section for details on how to use your API key.

The version of the OpenAPI document: 1.0.0
Contact: data@perigon.io
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set, Union

from pydantic import (
    BaseModel,
    ConfigDict,
    Field,
    StrictBool,
    StrictFloat,
    StrictInt,
    StrictStr,
)
from typing_extensions import Self

from perigon.models.category_holder import CategoryHolder
from perigon.models.category_with_score_holder import CategoryWithScoreHolder
from perigon.models.company_holder import CompanyHolder
from perigon.models.entity_holder import EntityHolder
from perigon.models.event_type_holder import EventTypeHolder
from perigon.models.id_name_holder import IdNameHolder
from perigon.models.journalist import Journalist
from perigon.models.keyword_holder import KeywordHolder
from perigon.models.label_holder import LabelHolder
from perigon.models.location_holder import LocationHolder
from perigon.models.person_holder import PersonHolder
from perigon.models.place import Place
from perigon.models.sentiment_holder import SentimentHolder
from perigon.models.source_holder import SourceHolder
from perigon.models.topic_holder import TopicHolder


class Article(BaseModel):
    """
    Article
    """  # noqa: E501

    url: Optional[StrictStr] = None
    authors_byline: Optional[StrictStr] = Field(default=None, alias="authorsByline")
    article_id: Optional[StrictStr] = Field(default=None, alias="articleId")
    cluster_id: Optional[StrictStr] = Field(default=None, alias="clusterId")
    source: Optional[SourceHolder] = None
    image_url: Optional[StrictStr] = Field(default=None, alias="imageUrl")
    country: Optional[StrictStr] = None
    language: Optional[StrictStr] = None
    pub_date: Optional[StrictStr] = Field(default=None, alias="pubDate")
    add_date: Optional[StrictStr] = Field(default=None, alias="addDate")
    refresh_date: Optional[StrictStr] = Field(default=None, alias="refreshDate")
    score: Optional[Union[StrictFloat, StrictInt]] = None
    title: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    content: Optional[StrictStr] = None
    en_content_word_count: Optional[StrictInt] = Field(
        default=None, alias="enContentWordCount"
    )
    medium: Optional[StrictStr] = None
    links: Optional[List[StrictStr]] = None
    labels: Optional[List[LabelHolder]] = None
    event_types: Optional[List[EventTypeHolder]] = Field(
        default=None, alias="eventTypes"
    )
    matched_authors: Optional[List[IdNameHolder]] = Field(
        default=None, alias="matchedAuthors"
    )
    claim: Optional[StrictStr] = None
    verdict: Optional[StrictStr] = None
    keywords: Optional[List[KeywordHolder]] = None
    topics: Optional[List[TopicHolder]] = None
    categories: Optional[List[CategoryHolder]] = None
    taxonomies: Optional[List[CategoryWithScoreHolder]] = None
    entities: Optional[List[EntityHolder]] = None
    companies: Optional[List[CompanyHolder]] = None
    sentiment: Optional[SentimentHolder] = None
    summary: Optional[StrictStr] = None
    short_summary: Optional[StrictStr] = Field(default=None, alias="shortSummary")
    translation: Optional[StrictStr] = None
    translated_title: Optional[StrictStr] = Field(default=None, alias="translatedTitle")
    translated_description: Optional[StrictStr] = Field(
        default=None, alias="translatedDescription"
    )
    translated_summary: Optional[StrictStr] = Field(
        default=None, alias="translatedSummary"
    )
    locations: Optional[List[LocationHolder]] = None
    reprint: Optional[StrictBool] = None
    reprint_group_id: Optional[StrictStr] = Field(default=None, alias="reprintGroupId")
    places: Optional[List[Place]] = None
    people: Optional[List[PersonHolder]] = None
    cluster: Optional[NewsCluster] = None
    journalists: Optional[List[Journalist]] = None
    highlights: Optional[Dict[str, List[StrictStr]]] = None
    __properties: ClassVar[List[str]] = [
        "url",
        "authorsByline",
        "articleId",
        "clusterId",
        "source",
        "imageUrl",
        "country",
        "language",
        "pubDate",
        "addDate",
        "refreshDate",
        "score",
        "title",
        "description",
        "content",
        "enContentWordCount",
        "medium",
        "links",
        "labels",
        "eventTypes",
        "matchedAuthors",
        "claim",
        "verdict",
        "keywords",
        "topics",
        "categories",
        "taxonomies",
        "entities",
        "companies",
        "sentiment",
        "summary",
        "shortSummary",
        "translation",
        "translatedTitle",
        "translatedDescription",
        "translatedSummary",
        "locations",
        "reprint",
        "reprintGroupId",
        "places",
        "people",
        "cluster",
        "journalists",
        "highlights",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Article from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of source
        if self.source:
            _dict["source"] = self.source.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in labels (list)
        _items = []
        if self.labels:
            for _item_labels in self.labels:
                if _item_labels:
                    _items.append(_item_labels.to_dict())
            _dict["labels"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in event_types (list)
        _items = []
        if self.event_types:
            for _item_event_types in self.event_types:
                if _item_event_types:
                    _items.append(_item_event_types.to_dict())
            _dict["eventTypes"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in matched_authors (list)
        _items = []
        if self.matched_authors:
            for _item_matched_authors in self.matched_authors:
                if _item_matched_authors:
                    _items.append(_item_matched_authors.to_dict())
            _dict["matchedAuthors"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in keywords (list)
        _items = []
        if self.keywords:
            for _item_keywords in self.keywords:
                if _item_keywords:
                    _items.append(_item_keywords.to_dict())
            _dict["keywords"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in topics (list)
        _items = []
        if self.topics:
            for _item_topics in self.topics:
                if _item_topics:
                    _items.append(_item_topics.to_dict())
            _dict["topics"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in categories (list)
        _items = []
        if self.categories:
            for _item_categories in self.categories:
                if _item_categories:
                    _items.append(_item_categories.to_dict())
            _dict["categories"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in taxonomies (list)
        _items = []
        if self.taxonomies:
            for _item_taxonomies in self.taxonomies:
                if _item_taxonomies:
                    _items.append(_item_taxonomies.to_dict())
            _dict["taxonomies"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in entities (list)
        _items = []
        if self.entities:
            for _item_entities in self.entities:
                if _item_entities:
                    _items.append(_item_entities.to_dict())
            _dict["entities"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in companies (list)
        _items = []
        if self.companies:
            for _item_companies in self.companies:
                if _item_companies:
                    _items.append(_item_companies.to_dict())
            _dict["companies"] = _items
        # override the default output from pydantic by calling `to_dict()` of sentiment
        if self.sentiment:
            _dict["sentiment"] = self.sentiment.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in locations (list)
        _items = []
        if self.locations:
            for _item_locations in self.locations:
                if _item_locations:
                    _items.append(_item_locations.to_dict())
            _dict["locations"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in places (list)
        _items = []
        if self.places:
            for _item_places in self.places:
                if _item_places:
                    _items.append(_item_places.to_dict())
            _dict["places"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in people (list)
        _items = []
        if self.people:
            for _item_people in self.people:
                if _item_people:
                    _items.append(_item_people.to_dict())
            _dict["people"] = _items
        # override the default output from pydantic by calling `to_dict()` of cluster
        if self.cluster:
            _dict["cluster"] = self.cluster.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in journalists (list)
        _items = []
        if self.journalists:
            for _item_journalists in self.journalists:
                if _item_journalists:
                    _items.append(_item_journalists.to_dict())
            _dict["journalists"] = _items
        # set to None if url (nullable) is None
        # and model_fields_set contains the field
        if self.url is None and "url" in self.model_fields_set:
            _dict["url"] = None

        # set to None if authors_byline (nullable) is None
        # and model_fields_set contains the field
        if self.authors_byline is None and "authors_byline" in self.model_fields_set:
            _dict["authorsByline"] = None

        # set to None if article_id (nullable) is None
        # and model_fields_set contains the field
        if self.article_id is None and "article_id" in self.model_fields_set:
            _dict["articleId"] = None

        # set to None if cluster_id (nullable) is None
        # and model_fields_set contains the field
        if self.cluster_id is None and "cluster_id" in self.model_fields_set:
            _dict["clusterId"] = None

        # set to None if source (nullable) is None
        # and model_fields_set contains the field
        if self.source is None and "source" in self.model_fields_set:
            _dict["source"] = None

        # set to None if image_url (nullable) is None
        # and model_fields_set contains the field
        if self.image_url is None and "image_url" in self.model_fields_set:
            _dict["imageUrl"] = None

        # set to None if country (nullable) is None
        # and model_fields_set contains the field
        if self.country is None and "country" in self.model_fields_set:
            _dict["country"] = None

        # set to None if language (nullable) is None
        # and model_fields_set contains the field
        if self.language is None and "language" in self.model_fields_set:
            _dict["language"] = None

        # set to None if pub_date (nullable) is None
        # and model_fields_set contains the field
        if self.pub_date is None and "pub_date" in self.model_fields_set:
            _dict["pubDate"] = None

        # set to None if add_date (nullable) is None
        # and model_fields_set contains the field
        if self.add_date is None and "add_date" in self.model_fields_set:
            _dict["addDate"] = None

        # set to None if refresh_date (nullable) is None
        # and model_fields_set contains the field
        if self.refresh_date is None and "refresh_date" in self.model_fields_set:
            _dict["refreshDate"] = None

        # set to None if score (nullable) is None
        # and model_fields_set contains the field
        if self.score is None and "score" in self.model_fields_set:
            _dict["score"] = None

        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict["title"] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict["description"] = None

        # set to None if content (nullable) is None
        # and model_fields_set contains the field
        if self.content is None and "content" in self.model_fields_set:
            _dict["content"] = None

        # set to None if en_content_word_count (nullable) is None
        # and model_fields_set contains the field
        if (
            self.en_content_word_count is None
            and "en_content_word_count" in self.model_fields_set
        ):
            _dict["enContentWordCount"] = None

        # set to None if medium (nullable) is None
        # and model_fields_set contains the field
        if self.medium is None and "medium" in self.model_fields_set:
            _dict["medium"] = None

        # set to None if links (nullable) is None
        # and model_fields_set contains the field
        if self.links is None and "links" in self.model_fields_set:
            _dict["links"] = None

        # set to None if labels (nullable) is None
        # and model_fields_set contains the field
        if self.labels is None and "labels" in self.model_fields_set:
            _dict["labels"] = None

        # set to None if event_types (nullable) is None
        # and model_fields_set contains the field
        if self.event_types is None and "event_types" in self.model_fields_set:
            _dict["eventTypes"] = None

        # set to None if matched_authors (nullable) is None
        # and model_fields_set contains the field
        if self.matched_authors is None and "matched_authors" in self.model_fields_set:
            _dict["matchedAuthors"] = None

        # set to None if claim (nullable) is None
        # and model_fields_set contains the field
        if self.claim is None and "claim" in self.model_fields_set:
            _dict["claim"] = None

        # set to None if verdict (nullable) is None
        # and model_fields_set contains the field
        if self.verdict is None and "verdict" in self.model_fields_set:
            _dict["verdict"] = None

        # set to None if keywords (nullable) is None
        # and model_fields_set contains the field
        if self.keywords is None and "keywords" in self.model_fields_set:
            _dict["keywords"] = None

        # set to None if topics (nullable) is None
        # and model_fields_set contains the field
        if self.topics is None and "topics" in self.model_fields_set:
            _dict["topics"] = None

        # set to None if categories (nullable) is None
        # and model_fields_set contains the field
        if self.categories is None and "categories" in self.model_fields_set:
            _dict["categories"] = None

        # set to None if taxonomies (nullable) is None
        # and model_fields_set contains the field
        if self.taxonomies is None and "taxonomies" in self.model_fields_set:
            _dict["taxonomies"] = None

        # set to None if entities (nullable) is None
        # and model_fields_set contains the field
        if self.entities is None and "entities" in self.model_fields_set:
            _dict["entities"] = None

        # set to None if companies (nullable) is None
        # and model_fields_set contains the field
        if self.companies is None and "companies" in self.model_fields_set:
            _dict["companies"] = None

        # set to None if sentiment (nullable) is None
        # and model_fields_set contains the field
        if self.sentiment is None and "sentiment" in self.model_fields_set:
            _dict["sentiment"] = None

        # set to None if summary (nullable) is None
        # and model_fields_set contains the field
        if self.summary is None and "summary" in self.model_fields_set:
            _dict["summary"] = None

        # set to None if short_summary (nullable) is None
        # and model_fields_set contains the field
        if self.short_summary is None and "short_summary" in self.model_fields_set:
            _dict["shortSummary"] = None

        # set to None if translation (nullable) is None
        # and model_fields_set contains the field
        if self.translation is None and "translation" in self.model_fields_set:
            _dict["translation"] = None

        # set to None if translated_title (nullable) is None
        # and model_fields_set contains the field
        if (
            self.translated_title is None
            and "translated_title" in self.model_fields_set
        ):
            _dict["translatedTitle"] = None

        # set to None if translated_description (nullable) is None
        # and model_fields_set contains the field
        if (
            self.translated_description is None
            and "translated_description" in self.model_fields_set
        ):
            _dict["translatedDescription"] = None

        # set to None if translated_summary (nullable) is None
        # and model_fields_set contains the field
        if (
            self.translated_summary is None
            and "translated_summary" in self.model_fields_set
        ):
            _dict["translatedSummary"] = None

        # set to None if locations (nullable) is None
        # and model_fields_set contains the field
        if self.locations is None and "locations" in self.model_fields_set:
            _dict["locations"] = None

        # set to None if reprint (nullable) is None
        # and model_fields_set contains the field
        if self.reprint is None and "reprint" in self.model_fields_set:
            _dict["reprint"] = None

        # set to None if reprint_group_id (nullable) is None
        # and model_fields_set contains the field
        if (
            self.reprint_group_id is None
            and "reprint_group_id" in self.model_fields_set
        ):
            _dict["reprintGroupId"] = None

        # set to None if places (nullable) is None
        # and model_fields_set contains the field
        if self.places is None and "places" in self.model_fields_set:
            _dict["places"] = None

        # set to None if people (nullable) is None
        # and model_fields_set contains the field
        if self.people is None and "people" in self.model_fields_set:
            _dict["people"] = None

        # set to None if cluster (nullable) is None
        # and model_fields_set contains the field
        if self.cluster is None and "cluster" in self.model_fields_set:
            _dict["cluster"] = None

        # set to None if journalists (nullable) is None
        # and model_fields_set contains the field
        if self.journalists is None and "journalists" in self.model_fields_set:
            _dict["journalists"] = None

        # set to None if highlights (nullable) is None
        # and model_fields_set contains the field
        if self.highlights is None and "highlights" in self.model_fields_set:
            _dict["highlights"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Article from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "url": obj.get("url"),
                "authorsByline": obj.get("authorsByline"),
                "articleId": obj.get("articleId"),
                "clusterId": obj.get("clusterId"),
                "source": (
                    SourceHolder.from_dict(obj["source"])
                    if obj.get("source") is not None
                    else None
                ),
                "imageUrl": obj.get("imageUrl"),
                "country": obj.get("country"),
                "language": obj.get("language"),
                "pubDate": obj.get("pubDate"),
                "addDate": obj.get("addDate"),
                "refreshDate": obj.get("refreshDate"),
                "score": obj.get("score"),
                "title": obj.get("title"),
                "description": obj.get("description"),
                "content": obj.get("content"),
                "enContentWordCount": obj.get("enContentWordCount"),
                "medium": obj.get("medium"),
                "links": obj.get("links"),
                "labels": (
                    [LabelHolder.from_dict(_item) for _item in obj["labels"]]
                    if obj.get("labels") is not None
                    else None
                ),
                "eventTypes": (
                    [EventTypeHolder.from_dict(_item) for _item in obj["eventTypes"]]
                    if obj.get("eventTypes") is not None
                    else None
                ),
                "matchedAuthors": (
                    [IdNameHolder.from_dict(_item) for _item in obj["matchedAuthors"]]
                    if obj.get("matchedAuthors") is not None
                    else None
                ),
                "claim": obj.get("claim"),
                "verdict": obj.get("verdict"),
                "keywords": (
                    [KeywordHolder.from_dict(_item) for _item in obj["keywords"]]
                    if obj.get("keywords") is not None
                    else None
                ),
                "topics": (
                    [TopicHolder.from_dict(_item) for _item in obj["topics"]]
                    if obj.get("topics") is not None
                    else None
                ),
                "categories": (
                    [CategoryHolder.from_dict(_item) for _item in obj["categories"]]
                    if obj.get("categories") is not None
                    else None
                ),
                "taxonomies": (
                    [
                        CategoryWithScoreHolder.from_dict(_item)
                        for _item in obj["taxonomies"]
                    ]
                    if obj.get("taxonomies") is not None
                    else None
                ),
                "entities": (
                    [EntityHolder.from_dict(_item) for _item in obj["entities"]]
                    if obj.get("entities") is not None
                    else None
                ),
                "companies": (
                    [CompanyHolder.from_dict(_item) for _item in obj["companies"]]
                    if obj.get("companies") is not None
                    else None
                ),
                "sentiment": (
                    SentimentHolder.from_dict(obj["sentiment"])
                    if obj.get("sentiment") is not None
                    else None
                ),
                "summary": obj.get("summary"),
                "shortSummary": obj.get("shortSummary"),
                "translation": obj.get("translation"),
                "translatedTitle": obj.get("translatedTitle"),
                "translatedDescription": obj.get("translatedDescription"),
                "translatedSummary": obj.get("translatedSummary"),
                "locations": (
                    [LocationHolder.from_dict(_item) for _item in obj["locations"]]
                    if obj.get("locations") is not None
                    else None
                ),
                "reprint": obj.get("reprint"),
                "reprintGroupId": obj.get("reprintGroupId"),
                "places": (
                    [Place.from_dict(_item) for _item in obj["places"]]
                    if obj.get("places") is not None
                    else None
                ),
                "people": (
                    [PersonHolder.from_dict(_item) for _item in obj["people"]]
                    if obj.get("people") is not None
                    else None
                ),
                "cluster": (
                    NewsCluster.from_dict(obj["cluster"])
                    if obj.get("cluster") is not None
                    else None
                ),
                "journalists": (
                    [Journalist.from_dict(_item) for _item in obj["journalists"]]
                    if obj.get("journalists") is not None
                    else None
                ),
                "highlights": obj.get("highlights"),
            }
        )
        return _obj


from perigon.models.news_cluster import NewsCluster

# TODO: Rewrite to not use raise_errors
Article.model_rebuild(raise_errors=False)



# coding: utf-8

"""
Perigon API

The Perigon API provides access to comprehensive news and web content data. To use the API, simply sign up for a Perigon Business Solutions account to obtain your API key. Your available features may vary based on your plan. See the Authentication section for details on how to use your API key.

The version of the OpenAPI document: 1.0.0
Contact: data@perigon.io
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing_extensions import Self

from perigon.models.symbol_holder import SymbolHolder
from perigon.models.web_resources import WebResources


class Company(BaseModel):
    """
    Company
    """  # noqa: E501

    id: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    updated_at: Optional[StrictStr] = Field(default=None, alias="updatedAt")
    primary_record_id: Optional[StrictStr] = Field(
        default=None, alias="primaryRecordId"
    )
    alt_names: Optional[List[StrictStr]] = Field(default=None, alias="altNames")
    domains: Optional[List[StrictStr]] = None
    monthly_visits: Optional[StrictInt] = Field(default=None, alias="monthlyVisits")
    global_rank: Optional[StrictInt] = Field(default=None, alias="globalRank")
    description: Optional[StrictStr] = None
    ceo: Optional[StrictStr] = None
    industry: Optional[StrictStr] = None
    sector: Optional[StrictStr] = None
    country: Optional[StrictStr] = None
    full_time_employees: Optional[StrictInt] = Field(
        default=None, alias="fullTimeEmployees"
    )
    address: Optional[StrictStr] = None
    city: Optional[StrictStr] = None
    state: Optional[StrictStr] = None
    zip: Optional[StrictStr] = None
    logo: Optional[StrictStr] = None
    favicon: Optional[StrictStr] = None
    is_etf: Optional[StrictBool] = Field(default=None, alias="isEtf")
    is_actively_trading: Optional[StrictBool] = Field(
        default=None, alias="isActivelyTrading"
    )
    is_fund: Optional[StrictBool] = Field(default=None, alias="isFund")
    is_adr: Optional[StrictBool] = Field(default=None, alias="isAdr")
    symbols: Optional[List[SymbolHolder]] = None
    naics: Optional[StrictStr] = None
    sic: Optional[StrictStr] = None
    year_founded: Optional[StrictInt] = Field(default=None, alias="yearFounded")
    revenue: Optional[StrictStr] = None
    web_resources: Optional[WebResources] = Field(default=None, alias="webResources")
    __properties: ClassVar[List[str]] = [
        "id",
        "name",
        "updatedAt",
        "primaryRecordId",
        "altNames",
        "domains",
        "monthlyVisits",
        "globalRank",
        "description",
        "ceo",
        "industry",
        "sector",
        "country",
        "fullTimeEmployees",
        "address",
        "city",
        "state",
        "zip",
        "logo",
        "favicon",
        "isEtf",
        "isActivelyTrading",
        "isFund",
        "isAdr",
        "symbols",
        "naics",
        "sic",
        "yearFounded",
        "revenue",
        "webResources",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Company from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in symbols (list)
        _items = []
        if self.symbols:
            for _item_symbols in self.symbols:
                if _item_symbols:
                    _items.append(_item_symbols.to_dict())
            _dict["symbols"] = _items
        # override the default output from pydantic by calling `to_dict()` of web_resources
        if self.web_resources:
            _dict["webResources"] = self.web_resources.to_dict()
        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict["id"] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict["name"] = None

        # set to None if updated_at (nullable) is None
        # and model_fields_set contains the field
        if self.updated_at is None and "updated_at" in self.model_fields_set:
            _dict["updatedAt"] = None

        # set to None if primary_record_id (nullable) is None
        # and model_fields_set contains the field
        if (
            self.primary_record_id is None
            and "primary_record_id" in self.model_fields_set
        ):
            _dict["primaryRecordId"] = None

        # set to None if alt_names (nullable) is None
        # and model_fields_set contains the field
        if self.alt_names is None and "alt_names" in self.model_fields_set:
            _dict["altNames"] = None

        # set to None if domains (nullable) is None
        # and model_fields_set contains the field
        if self.domains is None and "domains" in self.model_fields_set:
            _dict["domains"] = None

        # set to None if monthly_visits (nullable) is None
        # and model_fields_set contains the field
        if self.monthly_visits is None and "monthly_visits" in self.model_fields_set:
            _dict["monthlyVisits"] = None

        # set to None if global_rank (nullable) is None
        # and model_fields_set contains the field
        if self.global_rank is None and "global_rank" in self.model_fields_set:
            _dict["globalRank"] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict["description"] = None

        # set to None if ceo (nullable) is None
        # and model_fields_set contains the field
        if self.ceo is None and "ceo" in self.model_fields_set:
            _dict["ceo"] = None

        # set to None if industry (nullable) is None
        # and model_fields_set contains the field
        if self.industry is None and "industry" in self.model_fields_set:
            _dict["industry"] = None

        # set to None if sector (nullable) is None
        # and model_fields_set contains the field
        if self.sector is None and "sector" in self.model_fields_set:
            _dict["sector"] = None

        # set to None if country (nullable) is None
        # and model_fields_set contains the field
        if self.country is None and "country" in self.model_fields_set:
            _dict["country"] = None

        # set to None if full_time_employees (nullable) is None
        # and model_fields_set contains the field
        if (
            self.full_time_employees is None
            and "full_time_employees" in self.model_fields_set
        ):
            _dict["fullTimeEmployees"] = None

        # set to None if address (nullable) is None
        # and model_fields_set contains the field
        if self.address is None and "address" in self.model_fields_set:
            _dict["address"] = None

        # set to None if city (nullable) is None
        # and model_fields_set contains the field
        if self.city is None and "city" in self.model_fields_set:
            _dict["city"] = None

        # set to None if state (nullable) is None
        # and model_fields_set contains the field
        if self.state is None and "state" in self.model_fields_set:
            _dict["state"] = None

        # set to None if zip (nullable) is None
        # and model_fields_set contains the field
        if self.zip is None and "zip" in self.model_fields_set:
            _dict["zip"] = None

        # set to None if logo (nullable) is None
        # and model_fields_set contains the field
        if self.logo is None and "logo" in self.model_fields_set:
            _dict["logo"] = None

        # set to None if favicon (nullable) is None
        # and model_fields_set contains the field
        if self.favicon is None and "favicon" in self.model_fields_set:
            _dict["favicon"] = None

        # set to None if is_etf (nullable) is None
        # and model_fields_set contains the field
        if self.is_etf is None and "is_etf" in self.model_fields_set:
            _dict["isEtf"] = None

        # set to None if is_actively_trading (nullable) is None
        # and model_fields_set contains the field
        if (
            self.is_actively_trading is None
            and "is_actively_trading" in self.model_fields_set
        ):
            _dict["isActivelyTrading"] = None

        # set to None if is_fund (nullable) is None
        # and model_fields_set contains the field
        if self.is_fund is None and "is_fund" in self.model_fields_set:
            _dict["isFund"] = None

        # set to None if is_adr (nullable) is None
        # and model_fields_set contains the field
        if self.is_adr is None and "is_adr" in self.model_fields_set:
            _dict["isAdr"] = None

        # set to None if symbols (nullable) is None
        # and model_fields_set contains the field
        if self.symbols is None and "symbols" in self.model_fields_set:
            _dict["symbols"] = None

        # set to None if naics (nullable) is None
        # and model_fields_set contains the field
        if self.naics is None and "naics" in self.model_fields_set:
            _dict["naics"] = None

        # set to None if sic (nullable) is None
        # and model_fields_set contains the field
        if self.sic is None and "sic" in self.model_fields_set:
            _dict["sic"] = None

        # set to None if year_founded (nullable) is None
        # and model_fields_set contains the field
        if self.year_founded is None and "year_founded" in self.model_fields_set:
            _dict["yearFounded"] = None

        # set to None if revenue (nullable) is None
        # and model_fields_set contains the field
        if self.revenue is None and "revenue" in self.model_fields_set:
            _dict["revenue"] = None

        # set to None if web_resources (nullable) is None
        # and model_fields_set contains the field
        if self.web_resources is None and "web_resources" in self.model_fields_set:
            _dict["webResources"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Company from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "id": obj.get("id"),
                "name": obj.get("name"),
                "updatedAt": obj.get("updatedAt"),
                "primaryRecordId": obj.get("primaryRecordId"),
                "altNames": obj.get("altNames"),
                "domains": obj.get("domains"),
                "monthlyVisits": obj.get("monthlyVisits"),
                "globalRank": obj.get("globalRank"),
                "description": obj.get("description"),
                "ceo": obj.get("ceo"),
                "industry": obj.get("industry"),
                "sector": obj.get("sector"),
                "country": obj.get("country"),
                "fullTimeEmployees": obj.get("fullTimeEmployees"),
                "address": obj.get("address"),
                "city": obj.get("city"),
                "state": obj.get("state"),
                "zip": obj.get("zip"),
                "logo": obj.get("logo"),
                "favicon": obj.get("favicon"),
                "isEtf": obj.get("isEtf"),
                "isActivelyTrading": obj.get("isActivelyTrading"),
                "isFund": obj.get("isFund"),
                "isAdr": obj.get("isAdr"),
                "symbols": (
                    [SymbolHolder.from_dict(_item) for _item in obj["symbols"]]
                    if obj.get("symbols") is not None
                    else None
                ),
                "naics": obj.get("naics"),
                "sic": obj.get("sic"),
                "yearFounded": obj.get("yearFounded"),
                "revenue": obj.get("revenue"),
                "webResources": (
                    WebResources.from_dict(obj["webResources"])
                    if obj.get("webResources") is not None
                    else None
                ),
            }
        )
        return _obj



# coding: utf-8

"""
Perigon API

The Perigon API provides access to comprehensive news and web content data. To use the API, simply sign up for a Perigon Business Solutions account to obtain your API key. Your available features may vary based on your plan. See the Authentication section for details on how to use your API key.

The version of the OpenAPI document: 1.0.0
Contact: data@perigon.io
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing_extensions import Self

from perigon.models.category_holder import CategoryHolder
from perigon.models.company_count import CompanyCount
from perigon.models.company_holder import CompanyHolder
from perigon.models.key_point import KeyPoint
from perigon.models.location_count import LocationCount
from perigon.models.location_holder import LocationHolder
from perigon.models.person_count import PersonCount
from perigon.models.person_holder import PersonHolder
from perigon.models.question import Question
from perigon.models.record_stat_holder import RecordStatHolder
from perigon.models.sentiment_holder import SentimentHolder
from perigon.models.source_holder import SourceHolder
from perigon.models.topic_holder import TopicHolder


class NewsCluster(BaseModel):
    """
    NewsCluster
    """  # noqa: E501

    created_at: Optional[StrictStr] = Field(default=None, alias="createdAt")
    updated_at: Optional[StrictStr] = Field(default=None, alias="updatedAt")
    initialized_at: Optional[StrictStr] = Field(default=None, alias="initializedAt")
    id: Optional[StrictStr] = None
    duplicate_of: Optional[StrictStr] = Field(default=None, alias="duplicateOf")
    slug: Optional[StrictStr] = None
    name: Optional[StrictStr] = None
    summary: Optional[StrictStr] = None
    short_summary: Optional[StrictStr] = Field(default=None, alias="shortSummary")
    summary_references: Optional[List[StrictStr]] = Field(
        default=None, alias="summaryReferences"
    )
    image_source: Optional[SourceHolder] = Field(default=None, alias="imageSource")
    image_url: Optional[StrictStr] = Field(default=None, alias="imageUrl")
    key_points: Optional[List[KeyPoint]] = Field(default=None, alias="keyPoints")
    questions: Optional[List[Question]] = None
    unique_sources: Optional[List[StrictStr]] = Field(
        default=None, alias="uniqueSources"
    )
    selected_articles: Optional[List[Article]] = Field(
        default=None, alias="selectedArticles"
    )
    sentiment: Optional[SentimentHolder] = None
    unique_count: Optional[StrictInt] = Field(default=None, alias="uniqueCount")
    reprint_count: Optional[StrictInt] = Field(default=None, alias="reprintCount")
    total_count: Optional[StrictInt] = Field(default=None, alias="totalCount")
    countries: Optional[List[RecordStatHolder]] = None
    top_countries: Optional[List[StrictStr]] = Field(default=None, alias="topCountries")
    topics: Optional[List[RecordStatHolder]] = None
    top_topics: Optional[List[TopicHolder]] = Field(default=None, alias="topTopics")
    categories: Optional[List[RecordStatHolder]] = None
    top_categories: Optional[List[CategoryHolder]] = Field(
        default=None, alias="topCategories"
    )
    taxonomies: Optional[List[RecordStatHolder]] = None
    top_taxonomies: Optional[List[CategoryHolder]] = Field(
        default=None, alias="topTaxonomies"
    )
    people: Optional[List[PersonCount]] = None
    top_people: Optional[List[PersonHolder]] = Field(default=None, alias="topPeople")
    companies: Optional[List[CompanyCount]] = None
    top_companies: Optional[List[CompanyHolder]] = Field(
        default=None, alias="topCompanies"
    )
    locations: Optional[List[LocationCount]] = None
    top_locations: Optional[List[LocationHolder]] = Field(
        default=None, alias="topLocations"
    )
    highlights: Optional[Dict[str, List[StrictStr]]] = None
    __properties: ClassVar[List[str]] = [
        "createdAt",
        "updatedAt",
        "initializedAt",
        "id",
        "duplicateOf",
        "slug",
        "name",
        "summary",
        "shortSummary",
        "summaryReferences",
        "imageSource",
        "imageUrl",
        "keyPoints",
        "questions",
        "uniqueSources",
        "selectedArticles",
        "sentiment",
        "uniqueCount",
        "reprintCount",
        "totalCount",
        "countries",
        "topCountries",
        "topics",
        "topTopics",
        "categories",
        "topCategories",
        "taxonomies",
        "topTaxonomies",
        "people",
        "topPeople",
        "companies",
        "topCompanies",
        "locations",
        "topLocations",
        "highlights",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of NewsCluster from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of image_source
        if self.image_source:
            _dict["imageSource"] = self.image_source.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in key_points (list)
        _items = []
        if self.key_points:
            for _item_key_points in self.key_points:
                if _item_key_points:
                    _items.append(_item_key_points.to_dict())
            _dict["keyPoints"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in questions (list)
        _items = []
        if self.questions:
            for _item_questions in self.questions:
                if _item_questions:
                    _items.append(_item_questions.to_dict())
            _dict["questions"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in selected_articles (list)
        _items = []
        if self.selected_articles:
            for _item_selected_articles in self.selected_articles:
                if _item_selected_articles:
                    _items.append(_item_selected_articles.to_dict())
            _dict["selectedArticles"] = _items
        # override the default output from pydantic by calling `to_dict()` of sentiment
        if self.sentiment:
            _dict["sentiment"] = self.sentiment.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in countries (list)
        _items = []
        if self.countries:
            for _item_countries in self.countries:
                if _item_countries:
                    _items.append(_item_countries.to_dict())
            _dict["countries"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in topics (list)
        _items = []
        if self.topics:
            for _item_topics in self.topics:
                if _item_topics:
                    _items.append(_item_topics.to_dict())
            _dict["topics"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in top_topics (list)
        _items = []
        if self.top_topics:
            for _item_top_topics in self.top_topics:
                if _item_top_topics:
                    _items.append(_item_top_topics.to_dict())
            _dict["topTopics"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in categories (list)
        _items = []
        if self.categories:
            for _item_categories in self.categories:
                if _item_categories:
                    _items.append(_item_categories.to_dict())
            _dict["categories"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in top_categories (list)
        _items = []
        if self.top_categories:
            for _item_top_categories in self.top_categories:
                if _item_top_categories:
                    _items.append(_item_top_categories.to_dict())
            _dict["topCategories"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in taxonomies (list)
        _items = []
        if self.taxonomies:
            for _item_taxonomies in self.taxonomies:
                if _item_taxonomies:
                    _items.append(_item_taxonomies.to_dict())
            _dict["taxonomies"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in top_taxonomies (list)
        _items = []
        if self.top_taxonomies:
            for _item_top_taxonomies in self.top_taxonomies:
                if _item_top_taxonomies:
                    _items.append(_item_top_taxonomies.to_dict())
            _dict["topTaxonomies"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in people (list)
        _items = []
        if self.people:
            for _item_people in self.people:
                if _item_people:
                    _items.append(_item_people.to_dict())
            _dict["people"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in top_people (list)
        _items = []
        if self.top_people:
            for _item_top_people in self.top_people:
                if _item_top_people:
                    _items.append(_item_top_people.to_dict())
            _dict["topPeople"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in companies (list)
        _items = []
        if self.companies:
            for _item_companies in self.companies:
                if _item_companies:
                    _items.append(_item_companies.to_dict())
            _dict["companies"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in top_companies (list)
        _items = []
        if self.top_companies:
            for _item_top_companies in self.top_companies:
                if _item_top_companies:
                    _items.append(_item_top_companies.to_dict())
            _dict["topCompanies"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in locations (list)
        _items = []
        if self.locations:
            for _item_locations in self.locations:
                if _item_locations:
                    _items.append(_item_locations.to_dict())
            _dict["locations"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in top_locations (list)
        _items = []
        if self.top_locations:
            for _item_top_locations in self.top_locations:
                if _item_top_locations:
                    _items.append(_item_top_locations.to_dict())
            _dict["topLocations"] = _items
        # set to None if created_at (nullable) is None
        # and model_fields_set contains the field
        if self.created_at is None and "created_at" in self.model_fields_set:
            _dict["createdAt"] = None

        # set to None if updated_at (nullable) is None
        # and model_fields_set contains the field
        if self.updated_at is None and "updated_at" in self.model_fields_set:
            _dict["updatedAt"] = None

        # set to None if initialized_at (nullable) is None
        # and model_fields_set contains the field
        if self.initialized_at is None and "initialized_at" in self.model_fields_set:
            _dict["initializedAt"] = None

        # set to None if id (nullable) is None
        # and model_fields_set contains the field
        if self.id is None and "id" in self.model_fields_set:
            _dict["id"] = None

        # set to None if duplicate_of (nullable) is None
        # and model_fields_set contains the field
        if self.duplicate_of is None and "duplicate_of" in self.model_fields_set:
            _dict["duplicateOf"] = None

        # set to None if slug (nullable) is None
        # and model_fields_set contains the field
        if self.slug is None and "slug" in self.model_fields_set:
            _dict["slug"] = None

        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict["name"] = None

        # set to None if summary (nullable) is None
        # and model_fields_set contains the field
        if self.summary is None and "summary" in self.model_fields_set:
            _dict["summary"] = None

        # set to None if short_summary (nullable) is None
        # and model_fields_set contains the field
        if self.short_summary is None and "short_summary" in self.model_fields_set:
            _dict["shortSummary"] = None

        # set to None if summary_references (nullable) is None
        # and model_fields_set contains the field
        if (
            self.summary_references is None
            and "summary_references" in self.model_fields_set
        ):
            _dict["summaryReferences"] = None

        # set to None if image_source (nullable) is None
        # and model_fields_set contains the field
        if self.image_source is None and "image_source" in self.model_fields_set:
            _dict["imageSource"] = None

        # set to None if image_url (nullable) is None
        # and model_fields_set contains the field
        if self.image_url is None and "image_url" in self.model_fields_set:
            _dict["imageUrl"] = None

        # set to None if key_points (nullable) is None
        # and model_fields_set contains the field
        if self.key_points is None and "key_points" in self.model_fields_set:
            _dict["keyPoints"] = None

        # set to None if questions (nullable) is None
        # and model_fields_set contains the field
        if self.questions is None and "questions" in self.model_fields_set:
            _dict["questions"] = None

        # set to None if unique_sources (nullable) is None
        # and model_fields_set contains the field
        if self.unique_sources is None and "unique_sources" in self.model_fields_set:
            _dict["uniqueSources"] = None

        # set to None if selected_articles (nullable) is None
        # and model_fields_set contains the field
        if (
            self.selected_articles is None
            and "selected_articles" in self.model_fields_set
        ):
            _dict["selectedArticles"] = None

        # set to None if sentiment (nullable) is None
        # and model_fields_set contains the field
        if self.sentiment is None and "sentiment" in self.model_fields_set:
            _dict["sentiment"] = None

        # set to None if unique_count (nullable) is None
        # and model_fields_set contains the field
        if self.unique_count is None and "unique_count" in self.model_fields_set:
            _dict["uniqueCount"] = None

        # set to None if reprint_count (nullable) is None
        # and model_fields_set contains the field
        if self.reprint_count is None and "reprint_count" in self.model_fields_set:
            _dict["reprintCount"] = None

        # set to None if total_count (nullable) is None
        # and model_fields_set contains the field
        if self.total_count is None and "total_count" in self.model_fields_set:
            _dict["totalCount"] = None

        # set to None if countries (nullable) is None
        # and model_fields_set contains the field
        if self.countries is None and "countries" in self.model_fields_set:
            _dict["countries"] = None

        # set to None if top_countries (nullable) is None
        # and model_fields_set contains the field
        if self.top_countries is None and "top_countries" in self.model_fields_set:
            _dict["topCountries"] = None

        # set to None if topics (nullable) is None
        # and model_fields_set contains the field
        if self.topics is None and "topics" in self.model_fields_set:
            _dict["topics"] = None

        # set to None if top_topics (nullable) is None
        # and model_fields_set contains the field
        if self.top_topics is None and "top_topics" in self.model_fields_set:
            _dict["topTopics"] = None

        # set to None if categories (nullable) is None
        # and model_fields_set contains the field
        if self.categories is None and "categories" in self.model_fields_set:
            _dict["categories"] = None

        # set to None if top_categories (nullable) is None
        # and model_fields_set contains the field
        if self.top_categories is None and "top_categories" in self.model_fields_set:
            _dict["topCategories"] = None

        # set to None if taxonomies (nullable) is None
        # and model_fields_set contains the field
        if self.taxonomies is None and "taxonomies" in self.model_fields_set:
            _dict["taxonomies"] = None

        # set to None if top_taxonomies (nullable) is None
        # and model_fields_set contains the field
        if self.top_taxonomies is None and "top_taxonomies" in self.model_fields_set:
            _dict["topTaxonomies"] = None

        # set to None if people (nullable) is None
        # and model_fields_set contains the field
        if self.people is None and "people" in self.model_fields_set:
            _dict["people"] = None

        # set to None if top_people (nullable) is None
        # and model_fields_set contains the field
        if self.top_people is None and "top_people" in self.model_fields_set:
            _dict["topPeople"] = None

        # set to None if companies (nullable) is None
        # and model_fields_set contains the field
        if self.companies is None and "companies" in self.model_fields_set:
            _dict["companies"] = None

        # set to None if top_companies (nullable) is None
        # and model_fields_set contains the field
        if self.top_companies is None and "top_companies" in self.model_fields_set:
            _dict["topCompanies"] = None

        # set to None if locations (nullable) is None
        # and model_fields_set contains the field
        if self.locations is None and "locations" in self.model_fields_set:
            _dict["locations"] = None

        # set to None if top_locations (nullable) is None
        # and model_fields_set contains the field
        if self.top_locations is None and "top_locations" in self.model_fields_set:
            _dict["topLocations"] = None

        # set to None if highlights (nullable) is None
        # and model_fields_set contains the field
        if self.highlights is None and "highlights" in self.model_fields_set:
            _dict["highlights"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of NewsCluster from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "createdAt": obj.get("createdAt"),
                "updatedAt": obj.get("updatedAt"),
                "initializedAt": obj.get("initializedAt"),
                "id": obj.get("id"),
                "duplicateOf": obj.get("duplicateOf"),
                "slug": obj.get("slug"),
                "name": obj.get("name"),
                "summary": obj.get("summary"),
                "shortSummary": obj.get("shortSummary"),
                "summaryReferences": obj.get("summaryReferences"),
                "imageSource": (
                    SourceHolder.from_dict(obj["imageSource"])
                    if obj.get("imageSource") is not None
                    else None
                ),
                "imageUrl": obj.get("imageUrl"),
                "keyPoints": (
                    [KeyPoint.from_dict(_item) for _item in obj["keyPoints"]]
                    if obj.get("keyPoints") is not None
                    else None
                ),
                "questions": (
                    [Question.from_dict(_item) for _item in obj["questions"]]
                    if obj.get("questions") is not None
                    else None
                ),
                "uniqueSources": obj.get("uniqueSources"),
                "selectedArticles": (
                    [Article.from_dict(_item) for _item in obj["selectedArticles"]]
                    if obj.get("selectedArticles") is not None
                    else None
                ),
                "sentiment": (
                    SentimentHolder.from_dict(obj["sentiment"])
                    if obj.get("sentiment") is not None
                    else None
                ),
                "uniqueCount": obj.get("uniqueCount"),
                "reprintCount": obj.get("reprintCount"),
                "totalCount": obj.get("totalCount"),
                "countries": (
                    [RecordStatHolder.from_dict(_item) for _item in obj["countries"]]
                    if obj.get("countries") is not None
                    else None
                ),
                "topCountries": obj.get("topCountries"),
                "topics": (
                    [RecordStatHolder.from_dict(_item) for _item in obj["topics"]]
                    if obj.get("topics") is not None
                    else None
                ),
                "topTopics": (
                    [TopicHolder.from_dict(_item) for _item in obj["topTopics"]]
                    if obj.get("topTopics") is not None
                    else None
                ),
                "categories": (
                    [RecordStatHolder.from_dict(_item) for _item in obj["categories"]]
                    if obj.get("categories") is not None
                    else None
                ),
                "topCategories": (
                    [CategoryHolder.from_dict(_item) for _item in obj["topCategories"]]
                    if obj.get("topCategories") is not None
                    else None
                ),
                "taxonomies": (
                    [RecordStatHolder.from_dict(_item) for _item in obj["taxonomies"]]
                    if obj.get("taxonomies") is not None
                    else None
                ),
                "topTaxonomies": (
                    [CategoryHolder.from_dict(_item) for _item in obj["topTaxonomies"]]
                    if obj.get("topTaxonomies") is not None
                    else None
                ),
                "people": (
                    [PersonCount.from_dict(_item) for _item in obj["people"]]
                    if obj.get("people") is not None
                    else None
                ),
                "topPeople": (
                    [PersonHolder.from_dict(_item) for _item in obj["topPeople"]]
                    if obj.get("topPeople") is not None
                    else None
                ),
                "companies": (
                    [CompanyCount.from_dict(_item) for _item in obj["companies"]]
                    if obj.get("companies") is not None
                    else None
                ),
                "topCompanies": (
                    [CompanyHolder.from_dict(_item) for _item in obj["topCompanies"]]
                    if obj.get("topCompanies") is not None
                    else None
                ),
                "locations": (
                    [LocationCount.from_dict(_item) for _item in obj["locations"]]
                    if obj.get("locations") is not None
                    else None
                ),
                "topLocations": (
                    [LocationHolder.from_dict(_item) for _item in obj["topLocations"]]
                    if obj.get("topLocations") is not None
                    else None
                ),
                "highlights": obj.get("highlights"),
            }
        )
        return _obj


from perigon.models.article import Article

# TODO: Rewrite to not use raise_errors
NewsCluster.model_rebuild(raise_errors=False)



# coding: utf-8

"""
Perigon API

The Perigon API provides access to comprehensive news and web content data. To use the API, simply sign up for a Perigon Business Solutions account to obtain your API key. Your available features may vary based on your plan. See the Authentication section for details on how to use your API key.

The version of the OpenAPI document: 1.0.0
Contact: data@perigon.io
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing_extensions import Self

from perigon.models.wikidata_label_holder import WikidataLabelHolder


class WikiData(BaseModel):
    """
    WikiData
    """  # noqa: E501

    page_id: Optional[StrictStr] = Field(default=None, alias="pageId")
    section_id: Optional[StrictStr] = Field(default=None, alias="sectionId")
    wiki_page_id: Optional[StrictInt] = Field(default=None, alias="wikiPageId")
    wiki_revision_id: Optional[StrictInt] = Field(default=None, alias="wikiRevisionId")
    wiki_revision_ts: Optional[StrictStr] = Field(default=None, alias="wikiRevisionTs")
    wiki_code: Optional[StrictStr] = Field(default=None, alias="wikiCode")
    wiki_namespace: Optional[StrictInt] = Field(default=None, alias="wikiNamespace")
    wiki_title: Optional[StrictStr] = Field(default=None, alias="wikiTitle")
    wikidata_id: Optional[StrictStr] = Field(default=None, alias="wikidataId")
    wikidata_instance_of: Optional[List[WikidataLabelHolder]] = Field(
        default=None, alias="wikidataInstanceOf"
    )
    redirect_titles: Optional[List[StrictStr]] = Field(
        default=None, alias="redirectTitles"
    )
    pageviews: Optional[StrictInt] = None
    title: Optional[StrictStr] = None
    style_level: Optional[StrictInt] = Field(default=None, alias="styleLevel")
    content: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = [
        "pageId",
        "sectionId",
        "wikiPageId",
        "wikiRevisionId",
        "wikiRevisionTs",
        "wikiCode",
        "wikiNamespace",
        "wikiTitle",
        "wikidataId",
        "wikidataInstanceOf",
        "redirectTitles",
        "pageviews",
        "title",
        "styleLevel",
        "content",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of WikiData from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in wikidata_instance_of (list)
        _items = []
        if self.wikidata_instance_of:
            for _item_wikidata_instance_of in self.wikidata_instance_of:
                if _item_wikidata_instance_of:
                    _items.append(_item_wikidata_instance_of.to_dict())
            _dict["wikidataInstanceOf"] = _items
        # set to None if page_id (nullable) is None
        # and model_fields_set contains the field
        if self.page_id is None and "page_id" in self.model_fields_set:
            _dict["pageId"] = None

        # set to None if section_id (nullable) is None
        # and model_fields_set contains the field
        if self.section_id is None and "section_id" in self.model_fields_set:
            _dict["sectionId"] = None

        # set to None if wiki_page_id (nullable) is None
        # and model_fields_set contains the field
        if self.wiki_page_id is None and "wiki_page_id" in self.model_fields_set:
            _dict["wikiPageId"] = None

        # set to None if wiki_revision_id (nullable) is None
        # and model_fields_set contains the field
        if (
            self.wiki_revision_id is None
            and "wiki_revision_id" in self.model_fields_set
        ):
            _dict["wikiRevisionId"] = None

        # set to None if wiki_revision_ts (nullable) is None
        # and model_fields_set contains the field
        if (
            self.wiki_revision_ts is None
            and "wiki_revision_ts" in self.model_fields_set
        ):
            _dict["wikiRevisionTs"] = None

        # set to None if wiki_code (nullable) is None
        # and model_fields_set contains the field
        if self.wiki_code is None and "wiki_code" in self.model_fields_set:
            _dict["wikiCode"] = None

        # set to None if wiki_namespace (nullable) is None
        # and model_fields_set contains the field
        if self.wiki_namespace is None and "wiki_namespace" in self.model_fields_set:
            _dict["wikiNamespace"] = None

        # set to None if wiki_title (nullable) is None
        # and model_fields_set contains the field
        if self.wiki_title is None and "wiki_title" in self.model_fields_set:
            _dict["wikiTitle"] = None

        # set to None if wikidata_id (nullable) is None
        # and model_fields_set contains the field
        if self.wikidata_id is None and "wikidata_id" in self.model_fields_set:
            _dict["wikidataId"] = None

        # set to None if wikidata_instance_of (nullable) is None
        # and model_fields_set contains the field
        if (
            self.wikidata_instance_of is None
            and "wikidata_instance_of" in self.model_fields_set
        ):
            _dict["wikidataInstanceOf"] = None

        # set to None if redirect_titles (nullable) is None
        # and model_fields_set contains the field
        if self.redirect_titles is None and "redirect_titles" in self.model_fields_set:
            _dict["redirectTitles"] = None

        # set to None if pageviews (nullable) is None
        # and model_fields_set contains the field
        if self.pageviews is None and "pageviews" in self.model_fields_set:
            _dict["pageviews"] = None

        # set to None if title (nullable) is None
        # and model_fields_set contains the field
        if self.title is None and "title" in self.model_fields_set:
            _dict["title"] = None

        # set to None if style_level (nullable) is None
        # and model_fields_set contains the field
        if self.style_level is None and "style_level" in self.model_fields_set:
            _dict["styleLevel"] = None

        # set to None if content (nullable) is None
        # and model_fields_set contains the field
        if self.content is None and "content" in self.model_fields_set:
            _dict["content"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of WikiData from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "pageId": obj.get("pageId"),
                "sectionId": obj.get("sectionId"),
                "wikiPageId": obj.get("wikiPageId"),
                "wikiRevisionId": obj.get("wikiRevisionId"),
                "wikiRevisionTs": obj.get("wikiRevisionTs"),
                "wikiCode": obj.get("wikiCode"),
                "wikiNamespace": obj.get("wikiNamespace"),
                "wikiTitle": obj.get("wikiTitle"),
                "wikidataId": obj.get("wikidataId"),
                "wikidataInstanceOf": (
                    [
                        WikidataLabelHolder.from_dict(_item)
                        for _item in obj["wikidataInstanceOf"]
                    ]
                    if obj.get("wikidataInstanceOf") is not None
                    else None
                ),
                "redirectTitles": obj.get("redirectTitles"),
                "pageviews": obj.get("pageviews"),
                "title": obj.get("title"),
                "styleLevel": obj.get("styleLevel"),
                "content": obj.get("content"),
            }
        )
        return _obj



# coding: utf-8

"""
Perigon API

The Perigon API provides access to comprehensive news and web content data. To use the API, simply sign up for a Perigon Business Solutions account to obtain your API key. Your available features may vary based on your plan. See the Authentication section for details on how to use your API key.

The version of the OpenAPI document: 1.0.0
Contact: data@perigon.io
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
from enum import Enum

from typing_extensions import Self


class SortBy(str, Enum):
    """
    SortBy
    """

    """
    allowed enum values
    """
    CREATEDAT = "createdAt"
    UPDATEDAT = "updatedAt"
    RELEVANCE = "relevance"
    COUNT = "count"
    TOTALCOUNT = "totalCount"

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SortBy from a JSON string"""
        return cls(json.loads(json_str))



# coding: utf-8

"""
Perigon API

The Perigon API provides access to comprehensive news and web content data. To use the API, simply sign up for a Perigon Business Solutions account to obtain your API key. Your available features may vary based on your plan. See the Authentication section for details on how to use your API key.

The version of the OpenAPI document: 1.0.0
Contact: data@perigon.io
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing_extensions import Self


class WikipediaSearchFilter(BaseModel):
    """
    Complex filter structure for Wikipedia page searches that supports nested logical operations (AND, OR, NOT) and multiple filtering criteria.
    """  # noqa: E501

    page_id: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter by specific Perigon page identifiers. Accepts either a single ID or an array of IDs. Returns only pages matching these IDs.",
        alias="pageId",
    )
    section_id: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter by specific section identifiers. Accepts either a single ID or an array of IDs. Returns only pages containing these sections.",
        alias="sectionId",
    )
    wiki_page_id: Optional[List[StrictInt]] = Field(
        default=None,
        description="Filter by specific Wikipedia page identifiers. Accepts either a single ID or an array of IDs. Returns only pages matching these IDs.",
        alias="wikiPageId",
    )
    wiki_revision_id: Optional[List[StrictInt]] = Field(
        default=None,
        description="Filter by specific Perigon page revision identifiers. Accepts either a single ID or an array of IDs. Returns only pages matching these IDs.",
        alias="wikiRevisionId",
    )
    wiki_code: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter by specific Wikipedia project codes. Returns only pages matching these projects.",
        alias="wikiCode",
    )
    wiki_namespace: Optional[List[StrictInt]] = Field(
        default=None,
        description="Filter by specific Wikipedia namespaces. Returns only pages matching these namespaces.",
        alias="wikiNamespace",
    )
    wikidata_id: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter by specific Wikidata entity IDs. Returns only pages whose Wikidata entities match those ids.",
        alias="wikidataId",
    )
    wikidata_instance_of_id: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter by specific Wikidata entity IDs. Returns only pages whose Wikidata entities are instances of provided ids.",
        alias="wikidataInstanceOfId",
    )
    wikidata_instance_of_label: Optional[List[StrictStr]] = Field(
        default=None,
        description="Filter by specific Wikidata entity labels. Returns only pages whose Wikidata entities are instances of these labels.",
        alias="wikidataInstanceOfLabel",
    )
    var_and: Optional[List[WikipediaSearchFilter]] = Field(
        default=None,
        description="Adds additional AND filter objects. These objects must be of the same type as the original filter object and will be combined with the existing filter using the AND logical operator.",
        alias="AND",
    )
    var_or: Optional[List[WikipediaSearchFilter]] = Field(
        default=None,
        description="Adds additional OR filter objects. These objects must be of the same type as the original filter object and will be combined with the existing filter using the OR logical operator.",
        alias="OR",
    )
    var_not: Optional[List[WikipediaSearchFilter]] = Field(
        default=None,
        description="A filter object for logical NOT operations",
        alias="NOT",
    )
    __properties: ClassVar[List[str]] = [
        "pageId",
        "sectionId",
        "wikiPageId",
        "wikiRevisionId",
        "wikiCode",
        "wikiNamespace",
        "wikidataId",
        "wikidataInstanceOfId",
        "wikidataInstanceOfLabel",
        "AND",
        "OR",
        "NOT",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of WikipediaSearchFilter from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in var_and (list)
        _items = []
        if self.var_and:
            for _item_var_and in self.var_and:
                if _item_var_and:
                    _items.append(_item_var_and.to_dict())
            _dict["AND"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in var_or (list)
        _items = []
        if self.var_or:
            for _item_var_or in self.var_or:
                if _item_var_or:
                    _items.append(_item_var_or.to_dict())
            _dict["OR"] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in var_not (list)
        _items = []
        if self.var_not:
            for _item_var_not in self.var_not:
                if _item_var_not:
                    _items.append(_item_var_not.to_dict())
            _dict["NOT"] = _items
        # set to None if page_id (nullable) is None
        # and model_fields_set contains the field
        if self.page_id is None and "page_id" in self.model_fields_set:
            _dict["pageId"] = None

        # set to None if section_id (nullable) is None
        # and model_fields_set contains the field
        if self.section_id is None and "section_id" in self.model_fields_set:
            _dict["sectionId"] = None

        # set to None if wiki_page_id (nullable) is None
        # and model_fields_set contains the field
        if self.wiki_page_id is None and "wiki_page_id" in self.model_fields_set:
            _dict["wikiPageId"] = None

        # set to None if wiki_revision_id (nullable) is None
        # and model_fields_set contains the field
        if (
            self.wiki_revision_id is None
            and "wiki_revision_id" in self.model_fields_set
        ):
            _dict["wikiRevisionId"] = None

        # set to None if wiki_code (nullable) is None
        # and model_fields_set contains the field
        if self.wiki_code is None and "wiki_code" in self.model_fields_set:
            _dict["wikiCode"] = None

        # set to None if wiki_namespace (nullable) is None
        # and model_fields_set contains the field
        if self.wiki_namespace is None and "wiki_namespace" in self.model_fields_set:
            _dict["wikiNamespace"] = None

        # set to None if wikidata_id (nullable) is None
        # and model_fields_set contains the field
        if self.wikidata_id is None and "wikidata_id" in self.model_fields_set:
            _dict["wikidataId"] = None

        # set to None if wikidata_instance_of_id (nullable) is None
        # and model_fields_set contains the field
        if (
            self.wikidata_instance_of_id is None
            and "wikidata_instance_of_id" in self.model_fields_set
        ):
            _dict["wikidataInstanceOfId"] = None

        # set to None if wikidata_instance_of_label (nullable) is None
        # and model_fields_set contains the field
        if (
            self.wikidata_instance_of_label is None
            and "wikidata_instance_of_label" in self.model_fields_set
        ):
            _dict["wikidataInstanceOfLabel"] = None

        # set to None if var_and (nullable) is None
        # and model_fields_set contains the field
        if self.var_and is None and "var_and" in self.model_fields_set:
            _dict["AND"] = None

        # set to None if var_or (nullable) is None
        # and model_fields_set contains the field
        if self.var_or is None and "var_or" in self.model_fields_set:
            _dict["OR"] = None

        # set to None if var_not (nullable) is None
        # and model_fields_set contains the field
        if self.var_not is None and "var_not" in self.model_fields_set:
            _dict["NOT"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of WikipediaSearchFilter from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "pageId": obj.get("pageId"),
                "sectionId": obj.get("sectionId"),
                "wikiPageId": obj.get("wikiPageId"),
                "wikiRevisionId": obj.get("wikiRevisionId"),
                "wikiCode": obj.get("wikiCode"),
                "wikiNamespace": obj.get("wikiNamespace"),
                "wikidataId": obj.get("wikidataId"),
                "wikidataInstanceOfId": obj.get("wikidataInstanceOfId"),
                "wikidataInstanceOfLabel": obj.get("wikidataInstanceOfLabel"),
                "AND": (
                    [WikipediaSearchFilter.from_dict(_item) for _item in obj["AND"]]
                    if obj.get("AND") is not None
                    else None
                ),
                "OR": (
                    [WikipediaSearchFilter.from_dict(_item) for _item in obj["OR"]]
                    if obj.get("OR") is not None
                    else None
                ),
                "NOT": (
                    [WikipediaSearchFilter.from_dict(_item) for _item in obj["NOT"]]
                    if obj.get("NOT") is not None
                    else None
                ),
            }
        )
        return _obj


# TODO: Rewrite to not use raise_errors
WikipediaSearchFilter.model_rebuild(raise_errors=False)
